/**
 * 资讯模块公用 js
 */
define("news/scripts/common/common", function(require, exports, module) {
    var appUtils = require("appUtils"),
	    gconfig = require("gconfig"),
	    global = gconfig.global,
	    HIscroll = require("hIscroll"),
	    external = require("external"),
	    layerUtils = require("layerUtils"),
	    pageSubMenuScroller = null, // 页面子菜单的滑动组件
	    leftHeaderIconDesc = {
			'1': '<a href="javascript:void(0);" class="icon_mail"><span></span></a>', // 邮箱
			'2': '<a href="javascript:void(0)" class="icon_back"><span></span></a>', // 返回
			'3': '<a href="javascript:void(0)" class="icon_search"><span></span></a>' // 搜索
		}, // 头部左边图标的描述对象，如果需要增加头部左边图标的类型，按如上格式增加配置，并且需要增加 BindHeaderEvent 方法中的绑定事件
		rightHeaderIconDesc = {
				'1': '<a href="javascript:void(0);" class="icon_refresh"><span></span></a>' // 刷新
		}, // 头部右边图标的描述对象，如果需要增加头部右边图标的类型，按如上格式配置，并且需要增加 BindHeaderEvent 方法中的绑定事件
		oCurHeaderDesc = {
				isShowSelIcon: false // 是否显示弹出层的三角形选择图标，如果需要头部弹出层菜单，将其设为 true
		}, // 当前头部的描述对象
		oSelMenuDesc = {
				/**
				 * title 弹出层菜单中文名
				 * indexPage 模块首页
				 */
				"news": {title: "要闻", indexPage: "business/importantNews"}
		}, // 弹出层选择菜单的描述对象，如果需要增加弹出层菜单项，按上述格式增加新的菜单配置
		oPageSubMenuDesc = {
				"news" : [
				           /**
				            * title 页面子菜单中文名
				            * id 菜单项所在 li 的 id
				            * toPage 点击事件的目标页面
				            * width 菜单项所在 li 的宽度，可不传，默认每个菜单项宽度为 100% 除以菜单个数
				            */
				           {"title": "要闻","id": "news_importantNews", "toPage": "business/importantNews"}, 		       
				           {"title": "自选股","id": "news_zxg", "toPage" : "business/optionalShares"},
				           {"title": "沪深","id": "news_huShen","toPage": "business/shAndSz"} 
				           //{"title": "港股通","id": "news_hongkong", "toPage" : ""}
				]
		}; // 页面子菜单的描述对象，如果增加了新的弹出层菜单项，按如上格式配置弹出层菜单项对应的模块内页面子菜单

    /**
     * 从安卓原生种获得数据
     * @param key 键Key
     * @returns JSON格式的js对象
     */
    function readMsgFromFile(key){
    	var temp = "";
    	var temp2 = {};
    	var results = {};
    	
//    	if(gconfig.platform != 0){
//    		var jsonMsg = {"moduleName":"","childModuleName":"","funcNo":"60100","key":key};
//    		temp = external.callMessage(jsonMsg);
//    	}
    	
    	//从壳子中获取数据
    	if(gconfig.platform != 0){
    		var jsonMsg = {"moduleName":"","childModuleName":"","funcNo":"55603","key":key};
    		temp = external.callMessage(jsonMsg);
    	}
    	
    	
    	if(temp != null && temp != undefined && temp.length > 0){
    		try{
    			temp2 = JSON.parse(temp);
    			if(temp2.error_no == 0 && temp2.result){
    				results = JSON.parse(temp2.result);//因为我们保存的是json格式的字符串,因此,result返回的是一个字串
    			}else{
    				results = temp2;
    			}
    		}catch(e){
    			console.log("readMsgFromFile解析JSON出错，错误日志："+e.message);
    		}
    		return results;
    	}
    	return results;
    }

    
    /**
     * 将数据存入本地文件中
     * @param key 键Key 
     * @param value 值value(JSON对象)
     * @returns 无
     */
    function writeMsgToFile(key,value){
    	if(gconfig.platform == 1){
    		try{
    			var jsonMsg = {"moduleName":"news","childModuleName":"","funcNo":"55602","key":key,"value":JSON.stringify(value)};
				external.callMessage(jsonMsg);
    		}catch(e){
    			console.log("writeMsgToFile解析JSON出错，错误日志："+e.message);
    		}
    	}else{//待修改
    		try{
    			var valueStr = JSON.stringify(value);
    			valueStr = valueStr.replace(/\(/g,"（");
    			valueStr = valueStr.replace(/\)/g,"）");
    			valueStr = valueStr.replace(/\!/g,"！");
    			valueStr = valueStr.replace(/\'/g,"’");
    			valueStr = valueStr.replace(/\#/g,"＃");
    			valueStr = valueStr.replace(/\*/g,"＊");
    			valueStr = valueStr.replace(/\./g,"．");
    			valueStr = valueStr.replace(/\~/g,"～");
    			valueStr = valueStr.replace(/\_/g,"-");


    			external.callMessage("55602",{'key':key,'value':valueStr});
    		}catch(e){
    			console.log("writeMsgToFile解析JSON出错，错误日志："+e.message);
    		}
    	}
    }
    /**
	 * 判断是否为空对象,如果为空返回true
	 */
	function isEmptyObject(obj){
		if(obj == null || typeof obj == "undefined"){
			return true;
		}else{
			for(var n in obj){return false} 
			return true; 
		}
	} 
	
	/**
	 * 初始化原生头部
	 * @param isShowTitle 可以不传，默认为true 即显示普通标题
	 * @param isLoding 可以不传，默认为false 即表示不刷新
	 * @param leftBtn 可以不传，左图标简称(数字,如果不显示请传0)
	 * @param rightBtn 可以不传，右图标简称(数字,如果不显示请传0)
	 */
	function initHeader(titleName,isShowTitle,leftBtn,rightBtn){
		leftBtn = typeof leftBtn == "undefined" ? "0":leftBtn;
		rightBtn = typeof rightBtn == "undefined" ? "0":rightBtn;
		titleName = typeof titleName == "undefined" ? "资讯":titleName;
		isShowTitle = typeof isShowTitle == "undefined" ? "1":(isShowTitle == true ? "1":"0");
		var sendMsgParams = {
				"titleName":titleName,	 
				"titleType":isShowTitle, 
				"leftBtn":leftBtn,			
				"rightBtn":rightBtn		
			};
		var jsonMsg = {"moduleName":"news","childModuleName":"","funcNo":"50008","titleName":titleName,"titleType":isShowTitle,"leftBtn":leftBtn,"rightBtn":rightBtn};
		external.callMessage(jsonMsg);
	}
	
	/**
	 * 控制刷新
	 * @param isLoding 可以不传，默认为false 即表示不刷新
	 * @param isShow 可以不传，默认为true 即显示
	 */
	function refreshStyle(isLoding,isShow){
		isShow = typeof isShow == "undefined" ? true:isShow;
		if(isShow){
			isLoding = typeof isLoding == "undefined" ? "2":(isLoding == true ? "3":"2");
			var sendMsgParams = {
				"rightBtn":isLoding	//右图标简称(数字,如果不显示请传0)
			};
			var jsonMsg = {"moduleName":"news","childModuleName":"","funcNo":"50008","rightBtn":isLoding};

		}else{
			var sendMsgParams = {
				"rightBtn":"0"		//右图标简称(数字,如果不显示请传0)
			};
			var jsonMsg = {"moduleName":"news","childModuleName":"","funcNo":"50008","rightBtn":"0"};
		}
		external.callMessage(jsonMsg);
	}
	
    /*
	 * 获得时间差，time 的格式为  yyyy-MM-dd HH:mm:ss
	 * 
	 * */
	function timeBucket(time){
		//发布日期   
		var ptime = time.replace(/\-/g, "/");
		_ptime = new Date(ptime);
		//当前日期
		var date = new Date(new Date());
		//两时间的毫秒差
		var s = date-_ptime;
		
		/*
		 * 判断发布文档时间与查看文档时间的具体时间差，
		 * 距离8个月的显示具体时间，
		 * 距离1 个月 到8 个月之间的，显示 *个月 前 ，
		 * 距离一个月之内的，显示 *天 前 
		 * 距离一天之内的，显示 *小时前，*分钟前，*秒前，
		 * 
		 * */
		if(s>=1000*60*60*24*30*12*4){//4年后
			return time;
		}else if((1000*60*60*24*30*12<=s)&&(s<1000*60*60*24*30*12*4)){//1年 到4年之间
			return ""+Math.floor(s/(1000*60*60*24*30*12))+" 年前";
		}else if((1000*60*60*24*30*1<=s)&&(s<1000*60*60*24*30*12)){//1 个月 到1年之间
			return ""+Math.floor(s/(1000*60*60*24*30))+" 个月前";
		}else if((1000*60*60*24*1<=s)&&(s<1000*60*60*24*30)){//一个月之内
			return ""+Math.floor(s/(1000*60*60*24))+" 天前";
		}else if((1000*60*60<=s)&&(s<1000*60*60*24*1)){//1天之内
			return ""+Math.floor(s/(1000*60*60))+" 小时前";
		}else if((1000*60<=s)&&(s<1000*60*60)){
			return ""+Math.floor(s/(1000*60))+" 分钟前";
		}else if((1000<=s)&&(s<1000*60)){
			return ""+Math.floor(s/(1000))+" 秒前";
		}else if((0<=s)&&(s<1000)){
			return "刚刚";
		}else if(s<0){
			return "刚刚";
		}
	}
	
	function firstLoadFunc(){
		$("#iTranEffect").fadeOut();
		
		getURL(); //获取原生url
		
		//JS重写，如果不重写，便是JS自带的
    	Number.prototype.toFixed=function (d) { 
    		var s=this+""; 
    	    if(!d)d=0; 
    		if(s.indexOf(".")==-1)s+="."; 
    		s+=new Array(d+1).join("0"); 
    		if(new RegExp("^(-|\\+)?(\\d+(\\.\\d{0,"+(d+1)+"})?)\\d*$").test(s)){
    			var s="0"+RegExp.$2,pm=RegExp.$1,a=RegExp.$3.length,b=true;
    			if(a==d+2){
    				a=s.match(/\d/g); 
    				if(parseInt(a[a.length-1])>4){
    					for(var i=a.length-2;i>=0;i--){
    						a[i]=parseInt(a[i])+1;
    						if(a[i]==10){
    							a[i]=0;
    							b=i!=1;
    						}else break;
    					}
    				}
    				s=a.join("").replace(new RegExp("(\\d+)(\\d{"+d+"})\\d$"),"$1.$2");
    			}if(b)s=s.substr(1); 
    			return (pm+s).replace(/\.$/,"");
    			}return this+"";
    	};
	}
	
	
	
	/**
	 * 获取原生url
	 * */
	function  getURL(){
  	    //调原生获取最快的IP
      	var tradeURL = external.callMessage({"moduleName":"news","serverName":"H5_INFO_URL","funcNo": "50112"});
		
      	//当前表示获取到了IP，并且没有报错得到回调数据
      	if(tradeURL && (tradeURL.error_no == 0)){
      		//得到回调数据中的URL
			var result = tradeURL.results[0].url;
			//得到URL后进行完整地址的拼接，拼接上的"/servlet/json"表示的是本机的访问路径
//          global.serverPath = result+"/servlet/json";//sso地址
			global.newsUrl = result+"/servlet/json";//资讯地址
//			global.validateimg = result+"/servlet/NewImage";//验证码
		}
	}
	
	
	
    /**
     * 改变资讯事件格式
     */
	function changeNewsTime(time){
		if(typeof time != "undefined" && time != null && time != ""){
			var date = new Date();
			date = date.getFullYear()+"-"+(parseInt(date.getUTCMonth())+1)+"-"+date.getDate();
			var yearTime = time.substring(0,10);
			var hourTime = time.substring(11,time.lenth);
			if(yearTime == date){
				time = hourTime.substring(0,5);
			}else{
				time = yearTime.substring(5,11);
			}
			return time;
		}else{
			return "";
		}
	}
	/**
	 * 改变资讯事件格式
	 */
	function changeNewsDetailTime(time){
		var date = new Date();
		date = date.getFullYear()+"-"+(parseInt(date.getUTCMonth())+1)+"-"+date.getDate();
		var yearTime = time.substring(0,10);
		var hourTime = time.substring(11,time.lenth);
			time =  yearTime.substring(5,11) + "    "+hourTime.substring(0,5) ;
		return time;
	}
    var common = {
    		timeBucket : timeBucket,
    		firstLoadFunc: firstLoadFunc,
    		readMsgFromFile:readMsgFromFile,
    		writeMsgToFile:writeMsgToFile,
    		isEmptyObject:isEmptyObject,
    		initHeader:initHeader,
    		refreshStyle:refreshStyle,
    		changeNewsTime:changeNewsTime,
    		changeNewsDetailTime:changeNewsDetailTime,
            queryMsg:undefined
    };

    module.exports = common;
});