define(function(require, exports, module) {

	var appUtils = require("appUtils");
	var gconfig = require("gconfig");
	var layerUtils = require("layerUtils");
	var external = require("external");

	/**
	 * 微信起始过渡页特殊的pageInit方法
	 * 这里没有prePageCode，而是负载元素pageCode
	 */
	function wxTransPageInit(parentPageCode, pageCode, param)
	{
		$("#stepLoadingDiv").hide();
		//增加过渡页面的标志位，兼容普通见面跳转过来
		if(!param){
			param = {};
		}
		param._isWxTransFlag = true;

		var pageUrl = gconfig.viewsPath + pageCode + ".html",
			pageId = pageCode.replaceAll("/", "_"),
			parentPageId = parentPageCode.replaceAll("/", "_"); //负载父元素ID

		try {
			if($("#"+pageId).length < 1) {
				require("ajax").loadHtml(pageUrl, function(htmlContent) {
					document.title = $(htmlContent).attr("data-pageTitle");
					$("#"+parentPageId).append(htmlContent); //保存这个page到parentPageCode
					$("#"+pageId+" img").each(function() { //设置图片scr地址，防止出错
						var src = $(this).attr("src");
						if(src && $(this).attr("data-serverImg")!="true") {
							$(this).attr("src", gconfig.imagesPath + src.substring(src.indexOf("images")+7));
						}
					});
					require.async(gconfig.scriptsPath+pageCode, function(page) {
						appUtils.setSStorageInfo("wxTransPage_pageParam", JSON.stringify(param));
						page.init(); //页面初始化
						page.bindPageEvent(); //事件绑定
					});
				}, true, false, false);
			} else {
				require.async(gconfig.scriptsPath+pageCode, function(page) {
					appUtils.setSStorageInfo("wxTransPage_pageParam", JSON.stringify(param));
					page.init(); //页面初始化
					page.bindPageEvent(); //事件绑定
				});
			}
		} catch(e) {
			console.printStackTrace(e);
		}
	}

	/**
	 * 微信起始过渡页特殊的getPageParam方法
	 */
	function wxGetPageParam(paramName)
	{
		 //根据_isWxTransFlag判断，兼容普通见面跳转过来
		var jsonParam = appUtils.getSStorageInfo("wxTransPage_pageParam");
		jsonParam = JSON.parse(jsonParam);
		if(jsonParam && jsonParam._isWxTransFlag){
			if(paramName) {
				return jsonParam[paramName];
			} else {
				return jsonParam;
			}
		} else {
			return appUtils.getPageParam(paramName);
		}
	}

	function firstLoadFunc() {
//		require("external");
		console.log("firstLoad...");
		appUtils.clearSStorage("_isLoginIn");
		$("#loading").fadeOut();
		SendMessageOk("open");
	}

	/**通知原生H5加载完成*/
	function SendMessageOk(moduleName){
		var param = {
			"moduleName":moduleName,
			"funcNo":"50100"
		};
		external.callMessage(param);
	}

	function filterLoginOut(data){
		var error_no = data.error_no;
		var error_info = data.error_info;
		if(error_no == "-999" ) {
			appUtils.clearSStorage("_isLoginIn");
			appUtils.clearSStorage("_loginInPageCode");
			appUtils.clearSStorage("_loginInPageParam");


			//其他清理工作...
			layerUtils.iAlert("由于您长时间没有操作，请重新登录...",-1,function(){
				//其他清理工作...
				appUtils.sendDirect("../open/index.html");
			});
			//appUtils.pageInit(appUtils.getSStorageInfo("_curPageCode"), gconfig.loginPage.pageCode, gconfig.loginPage.jsonParam);
		}
		if(error_no == "-10000" ) {
			appUtils.clearSStorage("_isLoginIn");
			appUtils.clearSStorage("_loginInPageCode");
			appUtils.clearSStorage("_loginInPageParam");
			//其他清理工作...
			layerUtils.iAlert("呦，出错了",-1,function(){
				//其他清理工作...
				appUtils.sendDirect("../open/index.html");
			});
		}
	}

	/**
	 * 权限校验
	 * @param checkInParam 校验判断依据
	 * "checkInParam": {
	 * 		"prePageCode": prePageCode,
	 * 		"pageCode": pageCode,
	 * 		"param": param,
	 * 		"isLastReq": isLastReq,
	 * 		"isShowWait": isShowWait,
	 * 		"isShowOverLay": isShowOverLay
	 *	}
	 */
	function checkPermission(checkInParam) {
		var prePageCode = checkInParam.prePageCode ;
		var pageCode = checkInParam.pageCode ;
		if(!prePageCode && gconfig.defaultPage.pageCode!=pageCode){
			//不能从地址直接跳转到其他页面
			layerUtils.iAlert("呦，出错了",-1,function(){
				//其他清理工作...
				appUtils.sendDirect("../open/index.html");
			});
			return false;
		}else if(!!prePageCode){
			//不能未登录直接跳到需要登录的页面，防止从链接跳转
			var _isLoginIn = appUtils.getSStorageInfo("_isLoginIn");
			if(!_isLoginIn && gconfig.defaultPage.pageCode!=pageCode && gconfig.loginPage.pageCode!=pageCode){
				//其他清理工作...
				layerUtils.iAlert("您还没有登录，请重新登录...",-1,function(){
					//其他清理工作...
					appUtils.sendDirect("../open/index.html");
				});
				return false;
			}
		}
		return true;
	}

	var common = {
		"firstLoadFunc": firstLoadFunc,
		"checkPermission": checkPermission,
		"filterLoginOut" : filterLoginOut,
		"wxTransPageInit": wxTransPageInit,
		"wxGetPageParam": wxGetPageParam
	};
	//暴露对外的接口
	module.exports = common;
});
