/**
 * 非现场手机开户前端service层调用接口
 * */
define(function(require, exports, module) {
	var appUtils = require("appUtils"),
		mobileService = "open/scripts/thinkive/service/mobileService";

	function MobileService() {
		this.serviceMap = {};
	}

	/***应用接口......................................................开始*/
	/**
	 * 查询系统配置(501936)
	 * @param sys_variable_name
	 */
	MobileService.prototype.getSystemConfig = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getSystemConfig(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getSystemConfig(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 短信验证码发送(501520)
	 * @param op_way 访问接口来源标识(0：pc,2：pad,3：手机)
	 * @param mobile_no 手机号码
	 * @param ip 客户IP地址
	 * @param mac 设备mac地址
	 * @param callback 回调函数
	 */
	MobileService.prototype.getSmsCode = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getSmsCode(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getSmsCode(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 登录短信验证码校验(501521)
	 * @param mobile_no 手机号码
	 * @param mobile_code 手机验证码
	 * @param login_flag 登录业务标准
	 * @param callback 回调函数
	 */
	MobileService.prototype.checkSmsCode = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.checkSmsCode(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.checkSmsCode(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 查询营业部数据(501503)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryBranch = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryBranch(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryBranch(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 获取数字证书申请责任书协议信息
	 * @param cert_flag 1中登协议，2自建证书协议,默认中登
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryCertAgreement = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryCertAgreement(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryCertAgreement(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 获取邮编信息
	 * @param addr 地址
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryPostid = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryPostid(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryPostid(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 流程更改
	 * @param user_id 用户编号
	 * @param uploadimg_flag 1：身份证上次成功
	 * @param opacctkind_flag 0：新开，1：转户
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryChangeState = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryChangeState(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryChangeState(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 查询用户信息
	 * @param user_id 用户编号
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryUserInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 获取数据字典
	 * @param enum_type "occupational"为职业,"adapter"为学历,"zqzhlx"为开通证券类型
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryDataDict = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryDataDict(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryDataDict(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 开户信息资料提交 (501528)
	 * @param user_id            客户编号
	 * @param infocolect_channel 信息来源渠道( 0：pc，2：pad，3：手机)
	 * @param idtype             证件类别(00 身份证)
	 * @param idno               身份证号
	 * @param custname           客户姓名
	 * @param birthday           生日
	 * @param idbegindate        证件开始日期
	 * @param idenddate          证件结束日期
	 * @param native             证件地址
	 * @param policeorg          签发机关
	 * @param usersex            性别(0男，1女)
	 * @param nationality        国籍(156)
	 * @param addr               联系地址
	 * @param postid             邮政编码
	 * @param edu                学历代码
	 * @param profession_code    职业代码
	 * @param branchno           营业部代码
	 * @param provinceno         省份
	 * @param cityno             城市
	 * @param ipaddr             IP地址
	 * @param macaddr            mac地址
	 * @param callback           回调函数
	 */
	MobileService.prototype.submitUserInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 账户系统存在性查询(501527)
	 * @param idtype 证件类型
	 * @param idno   身份证号码
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryUserInfoExistSys = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryUserInfoExistSys(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryUserInfoExistSys(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *  中登查询股东账号是否存在(501553)
	 * @param user_id 用户ID
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryUserInfoExistCompy = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryUserInfoExistCompy(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryUserInfoExistCompy(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *  转户模拟QQ视频通过同步用户信息专用 (501599)
	 * @param user_id 用户ID
	 * @param callback 回调函数
	 */
	MobileService.prototype.syncQQUserInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.syncQQUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.syncQQUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *  查询离线视频通过状态查询 (501546)
	 * @param user_id 用户ID
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryQQOfflineState = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryQQOfflineState(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryQQOfflineState(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 获取数字证书申请责任书协议信息 (501523)
	 * @param cert_flag 1中登协议，2自建证书协议
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryAgreementTitle = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryAgreementTitle(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryAgreementTitle(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 中登证书获取（501529）
	 * @param user_id 客户编号
	 * @param pkcs10  证书申请串(由手机壳子生成)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryCompyCart = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryCompyCart(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryCompyCart(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 自建证书获取，天威（501530）
	 * @param user_id 客户编号
	 * @param pkcs10  证书申请串(由手机壳子生成)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryMyselfCart = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryMyselfCart(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryMyselfCart(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *  开户协议列表获取(501531)--证书下载界面
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryOpenAgreement = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryOpenAgreement(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryOpenAgreement(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 开立资金账户与客户号(501533)
	 * @param user_id 客户编号
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryOpenAccount = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryOpenAccount(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryOpenAccount(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 开立中登账户(501534)
	 * @param user_id 客户编号
	 * @param sza_str 深A开通情况
	 * @param sha_str 沪A开通情况
	 * @param szfnd_str 深基金开通情况
	 * @param shfnd_str 沪基金开通情况
	 * @param opfnd_str 沪基金开通情况
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryOpenCompyAccount = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryOpenCompyAccount(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryOpenCompyAccount(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 中登签名批量验签（MD5方式）(501554)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryOpenCheckSign = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryOpenCheckSign(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryOpenCheckSign(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 天威签名批量验签（MD5方式）(501555)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryOpenCheckTsign = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryOpenCheckTsign(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryOpenCheckTsign(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 查询协议内容 (501524)
	 * @param protocol_id 协议ID
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryProtocolText = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryProtocolText(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryProtocolText(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 设置交易密码和资金密码(501535)
	 * @param user_id        用户编号
	 * @param acct_clientid  账户系统客户号
	 * @param password  密码
	 * @param pwd_type  密码类型(1:资金密码 2:交易密码)
	 * @param is_same  资金密码和交易密码是否一致(1:一致 0：不同)
	 * @param callback 回调函数
	 */
	MobileService.prototype.setAccountPwd = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.setAccountPwd(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.setAccountPwd(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 查询存管银行信息列表(501536)
	 * @param user_id     用户编号
	 * @param zzbindtype  自助绑定方式(1一步式，2预指定)
	 * @param zzispwd     自助一步式绑定是否需要密码(1需要，0不需要)
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryBankList = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryBankList(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryBankList(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 存管银行签约电子协议列表(501537)
	 * @param user_id     用户编号
	 * @param bankcode    银行代码
	 * @param callback    回调函数
	 */
	MobileService.prototype.queryBankProtocolList = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryBankProtocolList(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryBankProtocolList(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 存管银行绑定(501538)
	 * @param user_id          用户编号
	 * @param acct_clientid    账户系统客户号
	 * @param acct_fndacct     账户系统资金账号
	 * @param bank_code	       银行代码
	 * @param bank_account     银行账号
	 * @param bank_pwd         银行密码
	 * @param acct_clientid    存管绑定方式
	 * @param op_type          账户系统客户号(自助绑定方式：1一步式，2预指定)
	 * @param callback    回调函数
	 */
	MobileService.prototype.bindBank = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.bindBank(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.bindBank(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 驳回后修改资料 (501561)
	 * @param user_id     用户编号
	 * @param fieldname   驳回步骤(zj_pwd资金密码、trade_pwd交易密码、bind_bank三方存管、photo图片、workflowagain重新走流程、opacctkind_flag开户流程业务类型)
	 * @param callback    回调函数
	 */
	MobileService.prototype.rejectStep = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.rejectStep(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.rejectStep(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 查询风险评测题库(501539)
	 * @param user_id     用户编号
	 * @param callback    回调函数
	 */
	MobileService.prototype.queryRiskToc = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryRiskToc(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryRiskToc(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 获取视频地址 (501562)
	 * @param user_id     用户编号
	 * @param sub_id      问卷编号
	 * @param q_a_args    问卷答题字符串
	 * @param sub_id      问卷编号
	 *
	 * @param callback    回调函数
	 */
	MobileService.prototype.queryVideoAddress = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryVideoAddress(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryVideoAddress(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 提交视频见证预约信息(501545)
	 * @param user_id     用户编号
	 * @param qq          QQ号码
	 * @param deal_date   预约处理日期
	 * @param deal_time   预约处理时间
	 * @param callback    回调函数
	 */
	MobileService.prototype.submitQQApplay = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitQQApplay(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitQQApplay(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 获取回访问卷(501541)
	 * @param user_id     用户编号
	 * @param qq          QQ号码
	 * @param sub_id
	 * @param callback    回调函数
	 */
	MobileService.prototype.getVisitSub = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getVisitSub(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getVisitSub(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 提交问卷回访答案(501511)
	 * @param user_id     用户编号
	 * @param sub_id      回访问卷编号
	 * @param q_a_args    问卷答题字符串
	 * @param callback    回调函数
	 */
	MobileService.prototype.submitVisitAnswer = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitVisitAnswer(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitVisitAnswer(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 提交风险评测答案(501540)
	 * @param user_id     用户编号
	 * @param sub_id      回访问卷编号
	 * @param q_a_args    问卷答题字符串
	 * @param callback    回调函数
	 */
	MobileService.prototype.submitTestAnswer = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitTestAnswer(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitTestAnswer(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *	查询电子协议列表(501558)
	 * @param category_englishname 电子协议英文名
	 * @param category_no 类别编号
	 * @param econtract_no 协议编号
	 * @param callback 回调函数
	 */
	MobileService.prototype.queryProtocolList = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryProtocolList(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryProtocolList(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *	查询电子协议内容(501559)
	 * @param econtract_no 电子协议编号
	 * @param econtract_version 电子协议版本
	 * @param callback 回调函数
	 */
	MobileService.prototype.getProtocolInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getProtocolInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getProtocolInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 *	移动客户端版本检测 (501560)
	 * @param terminal_type 客户端类型
	 * @param callback 回调函数
	 */
	MobileService.prototype.getVersion = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getVersion(param, callback, isLastReq, isShowWait, timeOutFunc, dataType);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getVersion(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 获取当前省份、城市（501568）
	 * @param ip  ip地址
	 * @param callback 回调函数
	 */
	MobileService.prototype.getProvCity = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getProvCity(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getProvCity(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 身份证信息提交 (501569)
	 * @param user_id            客户编号
	 * @param infocolect_channel 信息来源渠道( 0：pc，2：pad，3：手机)
	 * @param idtype             证件类别(00 身份证)
	 * @param idno               身份证号
	 * @param custname           客户姓名
	 * @param birthday           生日
	 * @param idbegindate        证件开始日期
	 * @param idenddate          证件结束日期
	 * @param native             证件地址
	 * @param policeorg          签发机关
	 * @param usersex            性别(0男，1女)
	 * @param nationality        国籍(156)
	 * @param addr               联系地址
	 * @param postid             邮政编码
	 * @param edu                学历代码
	 * @param profession_code    职业代码
	 * @param branchno           营业部代码
	 * @param provinceno         省份
	 * @param cityno             城市
	 * @param ipaddr             IP地址
	 * @param macaddr            mac地址
	 * @param callback           回调函数
	 */
	MobileService.prototype.submitPhoto = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitPhoto(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitPhoto(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 获取rsa加密模块和公钥
	 * @param param  参数
	 * @param callback 回调函数
	 */
	MobileService.prototype.getRSAKey = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getRSAKey(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getRSAKey(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 上传身份证[501525]
	 */
	MobileService.prototype.uploadImg = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.uploadImg(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.uploadImg(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 上传大头照[501526]
	 */
	MobileService.prototype.uploadHeadImg = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.uploadHeadImg(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.uploadHeadImg(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 获取美女客服信息
	 */
	MobileService.prototype.getWaiterInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getWaiterInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getWaiterInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 微信登陆获取个人开户信息
	 */
	MobileService.prototype.getOpenInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getOpenInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getOpenInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 解绑微信号和手机号
	 */
	MobileService.prototype.unbundling = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.unbundling(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.unbundling(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 点赞
	 */
	MobileService.prototype.likeWaiter = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.likeWaiter(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.likeWaiter(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 提交信息【501512】
	 */
	MobileService.prototype.writeUserInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.writeUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.writeUserInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 提交私钥
	 */
	MobileService.prototype.submitPriKey = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitPriKey(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitPriKey(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 同步提交视频申请
	 * @param param
	 * @param callback
	 * @param isLastReq
	 * @param isShowWait
	 * @param timeOutFunc
	 */
	MobileService.prototype.submitApplay = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitApplay(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitApplay(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 功能：通知推送
	 * 入参：data：data(Y)
	 */
	MobileService.prototype.sendMsg = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.sendMsg(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.sendMsg(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501598]
	 * 入参：
	 */
	MobileService.prototype.queryCanChangeState = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryCanChangeState(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryCanChangeState(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501598]
	 * 入参：
	 */
	MobileService.prototype.queryChange = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.queryChange(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryChange(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**                               姿势识别                      ***/

	/**
	 * 功能：[501550]
	 * 入参：
	 */
	MobileService.prototype.identityRecognition = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.identityRecognition(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.identityRecognition(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501932]
	 * 入参：
	 */
	MobileService.prototype.faceRecognition = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.faceRecognition(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.faceRecognition(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501937]
	 * 入参：
	 */
	MobileService.prototype.querySampleImage = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.querySampleImage(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.querySampleImage(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};

	/**
	 * 功能：[501985]
	 * 入参：
	 */
	MobileService.prototype.uploadPoseImg = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.uploadPoseImg(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.uploadPoseImg(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501986]
	 * 入参：
	 */
	MobileService.prototype.submitPostApply = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.submitPostApply(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.submitPostApply(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501987]
	 * 入参：
	 */
	MobileService.prototype.syncCustInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.syncCustInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.syncCustInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501987]
	 * 入参：
	 */
	MobileService.prototype.setUploadPostTime = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.setUploadPostTime(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.setUploadPostTime(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501940]
	 * 入参：
	 */
	MobileService.prototype.setUploadrefer = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.setUploadrefer(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.setUploadrefer(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 功能：[501902]
	 * 入参：
	 */
	MobileService.prototype.getManagerInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getManagerInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getManagerInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 获取佣金信息
	 * @param param  参数
	 * @param callback 回调函数
	 */
	MobileService.prototype.getCommissionInfo = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getCommissionInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getCommissionInfo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


	/**
	 * 确认佣金信息
	 * @param param  参数
	 * @param callback 回调函数
	 */
	MobileService.prototype.confirmCommission = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.confirmCommission(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.confirmCommission(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 语音验证码发送(501960)
	 * @param param  参数
	 * @param callback 回调函数
	 */
	MobileService.prototype.getVoiceCode = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getVoiceCode(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getVoiceCode(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 * 照片合成(2000001)
	 * @param param  参数
	 * @param callback 回调函数
	 */
	MobileService.prototype.getAllPhoto = function(param, callback, isLastReq, isShowWait, timeOutFunc) {
		var service = this.serviceMap[mobileService];
		if (service) {
			service.getAllPhoto(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.getAllPhoto(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};


/************************************** 微信双向视频开始 ********************************/
	/**
     *  功能：查询营业时间【501512】
     *  入参： @param user_id  用户id
     */
	MobileService.prototype.queryVideoServiceTime  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if(service){
			service.queryVideoServiceTime(param, callback, isLastReq, isShowWait, timeOutFunc);
		}else{
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.queryVideoServiceTime(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 *  功能：客户排队【501570】
	 *  入参： @param user_id  用户id
	 *       @param nick_name用户昵称
	 *       @param org_id   客户所属营业部编号
	 */
	MobileService.prototype.applyForQueue  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.applyForQueue(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.applyForQueue(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
    *  功能：查询客户在当前队列的情况 是否轮到自己【501572】
    *  入参： @param user_id  用户id
    */
	MobileService.prototype.checkQueueInformation  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.checkQueueInformation(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.checkQueueInformation(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 *  功能：查询客户在当前队列的情况 是否轮到自己【501575】
	 *  入参： @param user_id  用户id
	 */
	MobileService.prototype.checkQueueStatus  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.checkQueueStatus(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.checkQueueStatus(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
     *  功能: 查询是否有坐席在线 【501581】
     *  入参： @param user_id  用户id
     */
	MobileService.prototype.querySeat  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.querySeat(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.querySeat(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	/**
	 *  功能： 查询当前客户的队列位置【501586】
	 *  入参： @param user_id  用户id
	 */
	MobileService.prototype.checkNumberBefore  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.checkNumberBefore(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.checkNumberBefore(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
	 /**
    *  功能：  视频见证之前用户退出向后台发起消息【501597】
    *  入参： @param user_id  用户id
    */
	MobileService.prototype.loginOutQuenceOnNotVideo  = function(param, callback, isLastReq, isShowWait, timeOutFunc)
	{
		var service = this.serviceMap[mobileService];
		if (service) {
			service.loginOutQuenceOnNotVideo(param, callback, isLastReq, isShowWait, timeOutFunc);
		} else {
			var This = this;
			require.async(mobileService, function(module) {
				if (module) {
					service = module.getInstance();
					This.serviceMap[mobileService] = service;
					service.loginOutQuenceOnNotVideo(param, callback, isLastReq, isShowWait, timeOutFunc);
				} else {
					alert("服务层，js模块类[" + mobileService + "]不存在!");
				}
			});
		}
	};
   /************************************** 微信双向视频结束 ********************************/

	/***应用接口......................................................结束*/

	/**
	 * 释放操作
	 */
	MobileService.prototype.destroy = function() {
		for (var key in this.serviceMap) {
			var service = this.serviceMap[key];
			service.destroy();
			delete this.serviceMap[key];
		}
		this.serviceMap = {};
	};

	function getInstance() {
		return new MobileService();
	}

	var service = {
		"getInstance": getInstance
	};

	// 暴露对外的接口
	module.exports = service;
});