/**
 * 交易模块公用js
 */
define(function(require, exports, module) {
    var appUtils = require("appUtils");
    var layerUtils = require("layerUtils");
    var gconfig = require("gconfig"); 
    var global = gconfig.global;
    var external = require("external");
    var validata = require("validatorUtil");
    var	service_credit = require("service_credit");
    var service_common = require("service_common");
    var service_hq = require("service_hq");
    var commonFunc = require("commonFunc");
	var logoutTimer = null; //登录超时定时检测定时器
	var nativePluginService = require("nativePluginService");
	var fileUrl_red =  ["./css/common_red.css","./css/style_red.css"];
	var fileUrl_blue = ["./css/common_blue.css","./css/style_blue.css"];
	var getHqStateTimer = null;//获取行情服务状态定时器
	var check_login_time = null;
	
	/**
	 * 绑定普通交易菜单事件（在交易登录登录成功后在切换头部菜单时的事件的动态绑定，在每个页面对应的JS中调用此方法便会达到通用效果）
	 */
	function bindStockEvent(_pageId){
		appUtils.bindEvent($(_pageId+'.tab_nav ul li a'), function(e){
			//将动态传过来的页面ID进行了格式化
			var pageCode = _pageId.replace("#","").replaceAll("_","/").replace(" ","");
			//点击$(_pageId+'.tab_nav ul li a')元素获取要跳转的页面，并且将要跳转的页面的路径进行格式化
			var topage = $(this).attr("to-page").replaceAll("_","/"); //获取跳转的页面
			
			if(topage == "credit/transferred/collateralTransfer"){
				//点击页面中的头部元素都会调用方法判断用户当前是否是登录状态
				commonFunc.isAStockLogin();
			}else if((pageCode == "credit/asset/asset" && topage == "banking/transfer")|| 
					 (pageCode == "credit/order/mainOrder" && topage == "banking/transfer")|| 
					 (pageCode == "credit/transferred/collateralTransfer" && topage == "banking/transfer")|| 
					 (pageCode == "credit/query/financingQuery" && topage == "banking/transfer")){
				appUtils.setSStorageInfo("whichAccount","credit_userInfo");
				appUtils.setSStorageInfo("whichPage",pageCode);
				appUtils.pageInit(pageCode,topage);	
			}else{
				appUtils.pageInit(pageCode,topage,{});	
			}
			e.stopPropagation();
		 });
	}
	
	/**
	 * 将数字转换为金钱格式
	 */
	function numToMoneyType(str){
		str = str + "";  //强制转换成字符串
		var sign = "";
		//负数变成了正数
		if(str < 0){
			sign = str.substring(0,1);
			str = str.substring(1,str.length);
		}
		//得到指定的元素的坐标的位置
		var index = str.indexOf(".");
		var afterStr = "";
		
		//找到了小数点（说明传过来的参数是有小数点的）
		if(index != -1){
			//取出小数点后的元素
			afterStr = str.substring(index,str.length);
			//取出小数点前的元素
			str = str.substring(0,index);
		}
		//获取去掉小数点前是多少位（定义三个变量并对变量一进行了赋值）
		var len = str.length, 
		lastIndex, 
		arr = []; 
		//说明小数点前面是有元素的
		while( len > 0 ){ 
			lastIndex = len; 
			len -= 3; 
			arr.unshift(str.substring(len, lastIndex)); 
		} 
		return ""+sign + arr.join(',') + afterStr; 
	}

	/**
	 * 启动用户登录超时定时检测
	 * */
	function initLogoutTime(){
		//启动账户登录检测定时器
		if(logoutTimer != null){
			clearInterval(logoutTimer);
			logoutTimer = null;
		}
		logoutTimer = setInterval(function(){
			var lastDoTime=appUtils.getSStorageInfo("_lastDoTime");
			//是否登录超时的时间判断（超时便清空session中放入的数据）
			if(new Date().getTime() - lastDoTime > 1000 * 60 * global.logoutTimeNum){   
				appUtils.clearSStorage("stock_userInfo"); 
				appUtils.clearSStorage("credit_userInfo");
				appUtils.setSStorageInfo("_isLoginIn","false");
				clearStateTime(); //清除行情定时器
				layerUtils.iLayerClose();
				$("#account_index .top_title .logout").hide();
				layerUtils.iAlert("登录超时,请重新登录",-1,function(){
					appUtils.pageInit($("body #content div.page[data-display=block]").attr("id").replaceAll("_","/"),"account/login");
					clearInterval(logoutTimer);
					logoutTimer = null;
				},"确定");
			}
		},5000);//5秒检测一次
	}
	function clearLogoutTime(){
		if(logoutTimer != null)
		{
			clearInterval(logoutTimer);
			logoutTimer = null;
		}
	}
	
	
	/**
	 * 交易需要向后台传入如下格式的字符串，传入的接口比较多，因此写在 common 里面
	 * @param return 字符串 市场代码:账户类别:证券账户,….
	 */
	function getStockAccountListStr(){
		var stockAccountListStr = [];
		//从session中拿出数据
		var StockAccount = JSON.parse(appUtils.getSStorageInfo("StockAccount" , true));
		var keys = Object.keys(StockAccount);
		for(var i = 0, length = keys.length; i < length; i++){
			/**
			 * exchange_type	交易市场类别	0：深A，1：深B，2：沪A，3：沪B，4：三板，F1：郑州交易所，F2：大连交易所
			 * holder_kind	股东账户类别	0：普通账户, 1：基金账户 2：法人账户 3：回购账户 4：机构账户 5：报价转让
			 */
			var curStockStr = null;
			var exchange_type = StockAccount[keys[i]].exchange_type; // 市场代码
			var holder_kind = StockAccount[keys[i]].holder_kind; // 账户类别
			var stock_account = StockAccount[keys[i]].stock_account; // 证券账户
			curStockStr = exchange_type + ":" + holder_kind + ":" + stock_account;
			//依次向数组中添加元素
			stockAccountListStr.push(curStockStr);
		}
		return stockAccountListStr.join(",");
	}
	
	/**
	 * 每个页面校验
	 */
	function checkPermission(checkInParam){
//	/**
//	 * 客户是否选择交易通道
//	 */
//		var stockStationName = "";
//		if(gconfig.platform == "1"){
//			stockStationName = JSON.parse(external.callMessage({"funcNo":"50043","key":"stockStationName"})).results[0].value;
//		}else if(gconfig.platform == "2"){
//			stockStationName = (external.callMessage({"funcNo":"50043","key":"stockStationName"})).results[0].value;
//		}else{
//			stockStationName = appUtils.getLStorageInfo("stockStationName");
//		}
//		
//		if(stockStationName && stockStationName != "null"){
//			var serverPathTrade = "";
//			var validateimg = "";
//			if(gconfig.platform == "1"){
//				serverPathTrade = JSON.parse(external.callMessage({"funcNo":"50043","key":"serverPathTrade"})).results[0].value;
//				validateimg = JSON.parse(external.callMessage({"funcNo":"50043","key":"validateimg"})).results[0].value;
//			}else if(gconfig.platform == "2"){
//				serverPathTrade = (external.callMessage({"funcNo":"50043","key":"serverPathTrade"})).results[0].value;
//				validateimg = JSON.parse(external.callMessage({"funcNo":"50043","key":"validateimg"})).results[0].value;
//			}else{
//				serverPathTrade = appUtils.getLStorageInfo("serverPathTrade");
//				validateimg = appUtils.getLStorageInfo("validateimg");
//			}
//			
//			if(serverPathTrade && validateimg  && serverPathTrade != "null" && validateimg != "null"){
//				global.serverPathTrade = serverPathTrade;
//				global.validateimg = validateimg;
//			}
//		}
//		var pageCode = checkInParam.pageCode;
//		if(pageCode=="stock/stockBuy" || pageCode=="stock/stockSell"){
//			var stock_userInfo = appUtils.getSStorageInfo("stock_userInfo");
//			var activePhone ="";
//			//获取activePhone
//			if(gconfig.platform == "1"){
//				activePhone = JSON.parse(external.callMessage({"funcNo":"50043","key":"activePhone"})).results[0].value;
//			}else if(gconfig.platform == "2"){
//				activePhone = appUtils.getLStorageInfo("acitve_phone");
//			}else{
//				activePhone = "13888888888";
//			}
//	        if(stock_userInfo && activePhone && activePhone!="null"){
//	    	    return true;
//	        }else if(!stock_userInfo && activePhone && activePhone!="null"){
//				appUtils.pageInit(checkInParam.prePageCode,"account/login",{"topage":pageCode});
//				return false;
//	        }else{
//	        	appUtils.pageInit(checkInParam.prePageCode,"account/activePhone",{}); 
//			 	return false;
//	        }
//		}
		return true;
	}
	
	/**
	 * 首次进入模块的时候，调用
	 */
	function firstLoadFunc(){
    	$("#loading").fadeOut(); //隐藏载入效果
    	//external.callMessage({"funcNo": "50100", "moduleName":"trade"});
    	getURL(); //获取原生url
    	// 重置登录注销时间
//		apprPageBind();
    	
//    	//短信激活
//    	var theme = null;
//		if(gconfig.platform != "0"){
//			theme = external.callMessage({"funcNo":"50043","key":"theme"}).results[0].value;
//		}else{
//			theme = appUtils.getLStorageInfo("theme");
//		}
//		if(theme && theme!="null"){
//			loadCSS(theme); //加载主题
//		}
//		setTimeout(function(){
//			//判断短信是否激活方法的调用
//	    	checkActive(function(data){
//	    		if(data=="true"){
//	    			appUtils.pageInit(null,"account/index",{});
//	    		}else{
//	    			appUtils.pageInit(null,"account/activePhone",{});
//	    		}	
//	    	});
//		}, 0);
    	
    	//重写JS的底层的方法
    	Number.prototype.toFixed=function (d) { 
    		var s=this+""; 
    	    if(!d)d=0; 
    		if(s.indexOf(".")==-1)s+="."; 
    		s+=new Array(d+1).join("0"); 
    		if(new RegExp("^(-|\\+)?(\\d+(\\.\\d{0,"+(d+1)+"})?)\\d*$").test(s)){
    			var s="0"+RegExp.$2,pm=RegExp.$1,a=RegExp.$3.length,b=true;
    			if(a==d+2){
    				a=s.match(/\d/g); 
    				if(parseInt(a[a.length-1])>4){
    					for(var i=a.length-2;i>=0;i--){
    						a[i]=parseInt(a[i])+1;
    						if(a[i]==10){
    							a[i]=0;
    							b=i!=1;
    						}else break;
    					}
    				}
    				s=a.join("").replace(new RegExp("(\\d+)(\\d{"+d+"})\\d$"),"$1.$2");
    			}if(b)s=s.substr(1); 
    			return (pm+s).replace(/\.$/,"");
    			}return this+"";
    	};
	}
	
	//扑捉页面操作事件
	function apprPageBind(){
//		_resetLoginTime();
//		_checkLoginTime();
		appUtils.bindEvent($("#afui"), function(e){
//			_resetLoginTime();
			var param = {};
		       param["funcNo"] = "60608";
		       param["out_time_flag"] = true;
		       param["moduleName"] = "trade";
		       external.callMessage(param);
			e.stopPropagation();
		}, "touchstart");
	}
	
	// 重置登录状态时间
	function _resetLoginTime(){
		if (appUtils.getSStorageInfo("stock_userInfo") || appUtils.getSStorageInfo("credit_userInfo")){
			// 重置登录注销时间
			console.log("重置登录状态时间：" + global.logoutTimeNum * 60 * 1000);
			nativePluginService.function50040({"key": "logining_time", "value": global.logoutTimeNum * 60 * 1000});
		}
	}
	
	//激活登录状态
	function _checkLoginTime(){
		if (!check_login_time){
			_timingCheckLoginS();
		}
	}
	
	//定时检测登录状态
	function _timingCheckLoginS(){
		if (appUtils.getSStorageInfo("stock_userInfo") || appUtils.getSStorageInfo("credit_userInfo")){
			check_login_time = setTimeout(function(){
				var logining_time = nativePluginService.function50041({"key": "logining_time"}).results[0].value,
					// 当前显示模块
//					isbottom = nativePluginService.function50041({"key": "isbottom"}).results[0].value;
					isbottom = document.hasFocus();
				if (+logining_time <= 0){
					if (+logining_time === -20000.5){
						clearTimeout(check_login_time);
						check_login_time = null;
					} else {
						clearStateTime(); //清楚行情定时器
						appUtils.clearSStorage("stock_userInfo");
						appUtils.clearSStorage("credit_userInfo");
						appUtils.clearSStorage(true);
						appUtils.setSStorageInfo("_isLoginIn", false);
						layerUtils.iLayerClose();
						$(".top_title .logout").hide();
						var page_code = $("body #content div.page[data-display=block]").attr("id").replaceAll("_","/");
						if (isbottom){
							layerUtils.iAlert("登录超时，请重新登录!", "0", _loginTimeOut);
						} else {
							_loginTimeOut();
						}
					}
					nativePluginService.function50040({"key": "logining_time", "value": ""});
				} else {
					if (isbottom){
						logining_time = logining_time - 6000;
						nativePluginService.function50040({"key": "logining_time", "value": logining_time});
						console.log("刷新登录状态时间：" + logining_time);
					}
					_timingCheckLoginS();
				}
			}, 6000);
		} else {
			if (check_login_time){
				clearTimeout(check_login_time);
				check_login_time = null;
			}
			nativePluginService.function50040({"key": "logining_time", "value": ""});
		}
	}
	
	/**
	 * 登录超时
	 */
	function _loginTimeOut(){
		clearTimeout(check_login_time);
        check_login_time = null;
        require.async("sso", function(module){
			module.ssoLoginOut();
//			module.goTologin(page_code);
		});
	}
	
	/**
	 * 判断激活
	 */
	function checkActive(callback){
		var token = "";
		//获取token（）
		if(gconfig.platform != "0"){
			token = external.callMessage({"funcNo":"50022"}).results[0].deviceToken;
		}else{
			token = "aabbccddeeffgg";
		}
		global.hardId = token+""; //获取硬件
		var activePhone ="";
		//获取activePhone
		if(gconfig.platform == "1"){
			activePhone = external.callMessage({"funcNo":"50043","key":"activePhone"}).results[0].value;
		}else if(gconfig.platform == "2"){
			activePhone = appUtils.getLStorageInfo("acitve_phone");
		}else{
			activePhone = appUtils.getLStorageInfo("acitve_phone");
		}
		global.activePhone = activePhone+""; //获取硬件
		if(activePhone && activePhone!="null"){
			var param = {
				"phone":activePhone,
				"hardsn":token
			};
			//查询客户是否激活
			service_common.queryBinDingCustomerPhone(param,function(data){
				if(data.error_no == 0){
					var results = data.results[0];
					if(typeof results != "undefined" && results != null && results != ""){
						var flag = results.flag;
						if(flag == 0 ){
							callback("false");
						}else{//激活不作处理
							callback("true");
						}
					}else{
						callback("false");
					}
				}else{
					callback("false");
				}
			});
		}else{
			callback("false");
		}
	}
	
	
	
	
	/**
	 * ios 解禁系统键盘
	 */
	function systemKeybord(){
		var curPageCode = appUtils.getSStorageInfo("_curPageCode").replaceAll("/","_");
//		var curPageCode = $("body #content div.page[data-display=block]").attr("id").replaceAll("/","_");
		$(function(){    //遍历
		   $("#"+curPageCode+" input").each(function(){
		      if($(this).attr("custom_keybord")=="0"){
		  		appUtils.bindEvent($(this), function(e){
		  			external.callMessage({"moduleName":"trade","funcNo": "50210", "pageId":curPageCode, "eleId":"", "doneLable":"done", "keyboardType":"9"});
					e.stopPropagation();
				},"click");
		      }
		    });
		});
	}
	
	
	/**
	 * 登录超时
	 */
	function filterLoginOut(){
		layerUtils.iMsg("","登录超时,请重新登陆","");
		var sCurPage = appUtils.getSStorageInfo("_curPage");
		appUtils.clearSStorage();
		clearStateTime(); //清楚行情定时器
		var curPage = JSON.parse(sCurPage);
		var pageCode = curPage.pageCode;
		$(".top_title .logout").hide();
		external.callMessage({"funcNo": "60202"});
		appUtils.pageInit(pageCode,"account/index",{"topage":pageCode});
	} 
	
	
	
	/**
	 * 股票小数保留位数
	 */
	function decimalKeep(stockType){  //小数保留
		var KEEP_TWO = 2;
		var KEEP_THREE = 3;
		var stockInfo = {};
		var keyTwonum = [0,1,2,7,9,15,18,25,26,27]; // 保留两位
		var step_flag = $.inArray(stockType, keyTwonum);
		var keepNum = KEEP_TWO;
		if(step_flag == -1){
			keepNum = KEEP_THREE;
		}else{
			keepNum = KEEP_TWO;
		}	
		var shbondType = [14,25,26,27,30]; // 上海债券
		var szbondType = [6,21,22,23,24]; // 深圳债券
		var shbond_flag = $.inArray(stockType, shbondType);
		var szbond_flag = $.inArray(stockType, szbondType);
		var is_bond = "0";
		if(shbond_flag != -1){
			is_bond = "1";
		}else if(szbond_flag != -1){
			is_bond = "2";
		}else{
			is_bond = "0";
		}
		stockInfo = {"keepNum":keepNum,"is_bond":is_bond};
	    return stockInfo;
	}
	/**
	 * 股票小数保留位数
	 */
	function decimalKeep1(stockType, func){  //小数保留
		var KEEP_TWO = 2;
		var KEEP_THREE = 3;
		var stockInfo = {};
		var keyTwonum = [0,1,2,7,9,15,18,25,26,27]; // 保留两位
		var step_flag = $.inArray(stockType, keyTwonum);
		var keepNum = KEEP_TWO;
		if(step_flag == -1){
			keepNum = KEEP_THREE;
		}else{
			keepNum = KEEP_TWO;
		}	
		var shbondType = [14,25,26,27,30]; // 上海债券
		var szbondType = [6,21,22,23,24]; // 深圳债券
		var shbond_flag = $.inArray(stockType, shbondType);
		var szbond_flag = $.inArray(stockType, szbondType);
		var is_bond = "0";
		if(shbond_flag != -1){
			is_bond = "1";
		}else if(szbond_flag != -1){
			is_bond = "2";
		}else{
			is_bond = "0";
		}
		stockInfo = {"keepNum":keepNum,"is_bond":is_bond};
		func(stockInfo);
	}
	
	/**
	 * 得到证券类型
	 */
	function getStockType(stkType){
		var typeName = "股票";
		var bondType = [6,14,21,22,23,24,25,26,27,30]; // 债券
		var fundType = [3,4,11,12,19,20]; // 基金
		var warrantType = [5,13]; // 权证
		if($.inArray(stkType, bondType)!=-1){
			typeName = "债券";
		}else if($.inArray(stkType, fundType)!=-1){
			typeName = "基金";
		}else if($.inArray(stkType, warrantType)!=-1){
			typeName = "权证";
		}else{
			typeName = "股票";
		}
		return typeName;
	}
	
	/**
	 * IOS下拉卡屏问题
	 */
	function appDownStop(ev){
		appUtils.bindEvent($("body"),function(e){
			var touch = e.targetTouches[0] || event.targetTouches[0];
			var y = Number(touch.pageY); //页面触点Y坐标
			var yHeight = Number($(" #content").height());
			if(gconfig.platform == "2"){
				if(y >= (yHeight-1)){
					if($(_pageId + " .visc_flip").css("display") == "block"){
						if(vIscroll._init){
							vIscroll.scroll.refresh();
						}	        	
					}
				}
				if(y < 10){
					if($(_pageId + " .visc_flip").css("display") == "block"){
						if(vIscroll._init){
							vIscroll.scroll.refresh();
						}	        	
					}
				}
			}
		},"touchmove");
	}

	/**
	 * H5换肤
	 */
	function loadCSS(theme){  	
		var color = {
			'0': fileUrl_red,   // 红色
			'1': fileUrl_blue   // 蓝色
	    };
	    if(theme != "0" && theme != "1" ){
	    	theme = "0";
	    }
	    
	    var oHead = document.getElementsByTagName('head').item(0);
	    var fileUrl = color[theme];   //fileUrl等于color[fileUrl_red]或者color[fileUrl_blue]
	    
	    for(var i=0;i<fileUrl.length;i++){
	    	var cssTag = document.getElementById(fileUrl+i);
	    	if (cssTag) oHead.removeChild(cssTag); 
	    	var ocss= document.createElement("link");
		    ocss.id= fileUrl+i;
		    ocss.href = fileUrl[i]; 
		    ocss.rel = "stylesheet"; 
		    ocss.charset= "uf-8";
	    	oHead.appendChild(ocss); 
	    }
	    
	    //保存主题颜色
		if(gconfig.platform != "0"){
			external.callMessage({"funcNo":"50042","key":"theme","value":theme});
			appUtils.setLStorageInfo("theme",theme);
		}else{
			appUtils.setLStorageInfo("theme",theme);
		}
	}
	
	/**
	 * 启动行情服务器定时检测（时时检测是否在交易时间）
	 * */
	function initStateTime(){
		//启动更新个股数据定时器
		if(getHqStateTimer != null){
			clearInterval(getHqStateTimer);
			getHqStateTimer = null;
		}
		getHqStateTimer = setInterval(function(){
			getHqState();
		}, 60000);//1分钟
	}
	/**
	 * 清除行情服务器定时检测
	 * */
	function clearStateTime(){
		//启动更新个股数据定时器
		if(getHqStateTimer != null){
			clearInterval(getHqStateTimer);
			getHqStateTimer = null;
			global.isTrade =  false;
		}
	}
	
	/**
	 * 获取行情服务器状态
	 * */
	function  getHqState(){
		service_hq.getHqState(null,getHqStateCallBack,{"isShowWait":false});
	}
	/**
	 * 获取行情服务器状态返回
	 * */
	function getHqStateCallBack(data){
		if(data != null ){
			var result = data.results;
			if(result.length>0){//取行情服务器时间
				var obj = result[0];
				var hvDate = Number(obj[2].toString().substring(0,8));   //转码机时间
				var hqServerDate = Number(obj[1].toString().substring(0,8));   //行情时间
				var hqServerTime = Number(Number(obj[3].toString().substring(8,12)));   //行情服务器机器时间
				
				//判断是否是交易时间（转码机的时间和行情时间如果不相同便不再交易时间内）
				if(hvDate != hqServerDate){
					global.isTrade =  false;
					
				//当前表示转码机的时间和行情时间相同
				}else{
					//判断行情服务器时间是否（继续判断是否在交易时间内）
					if((hqServerTime > 928 && hqServerTime < 1132) || (hqServerTime > 1258 && hqServerTime < 1502)){
						global.isTrade =  true;
					}else{
						global.isTrade =  false;
					}
				}
			
			//当前表示请求成功，无数据返回
			}else{//取客户端时间
				var time = new Date().format("HHmmss");
				var timeNumber = parseFloat(time);
				if((93000 <= timeNumber && timeNumber <= 113000)||(130000 <= timeNumber && timeNumber <= 150000)){
					global.isTrade =  true;
				}
				else{
					global.isTrade =  false;
				}
			}
		
		//表示请求没有任何的数据
		}else{//取客户端时间
			var time = new Date().format("HHmmss");
			var timeNumber = parseFloat(time);
			if((93000 <= timeNumber && timeNumber <= 113000)||(130000 <= timeNumber && timeNumber <= 150000)){
				global.isTrade = true;
			}
			else{
				global.isTrade = false;
			}
		}
		
		global.isTrade = true;
	}
	
	
	/**
	 * 获取原生url
	 * */
	function  getURL(){
  	    //调原生获取最快的IP
      	var tradeURL = external.callMessage({"moduleName":"trade","serverName":"TRADE_URL","funcNo": "50112"});
		
      	//当前表示获取到了IP，并且没有报错得到回调数据
      	if(tradeURL && (tradeURL.error_no == 0)){
      		//得到回调数据中的URL
			var result = tradeURL.results[0].url;
			//得到URL后进行完整地址的拼接，拼接上的"/servlet/json"表示的是本机的访问路径
            global.serverPath = result+"/servlet/json";//sso地址
			global.serverPathTrade = result+"/servlet/json";//交易地址
			global.validateimg = result+"/servlet/NewImage";//验证码
		}
		
		var newshareURL = external.callMessage({"moduleName":"trade","serverName":"INFO_URL","funcNo": "50112"});
		if(newshareURL && (newshareURL.error_no == 0)){
			var result = newshareURL.results[0].url;
			global.newshareUrl = result;//新股
		}
		
		var hqURL = external.callMessage({"moduleName":"trade","serverName":"HQ_URL_HTTP","funcNo": "50112"});
		if(hqURL && (hqURL.error_no == 0)){
			var result = hqURL.results[0].url;
			global.HqUrl = result;//行情
		}
	}
	
	// 自定义弹出层
	function btnConfirm(conMsg, yesFunc, noFunc, yesBtnWords, noBtnWords){
		    var iAlertIdx = -9999;
		    //弹出层的DIV的定义
			var viewContent ="<div class=\"backdrop\" style=\"display:block;\"></div>";
			viewContent +="<div class=\"pop_box pop_cancel pop\" id=\"pop_tip_confirm\" style=\"top:40%;display:block\">";
			viewContent += conMsg;
			viewContent +="    <div class=\"pop_footer\">";
			viewContent +="   	<div class=\"pop_btn two\">";
			viewContent +="  		<a href=\"javascript:void(0);\" id=\"pop_tip_confirm_yes\">"+(yesBtnWords||"确 定")+"</a><a href=\"javascript:void(0);\" id=\"pop_tip_confirm_no\">"+(noBtnWords||"取消")+"</a>";
			viewContent +="     </div>";
			viewContent +="   </div>";
			viewContent +="</div>";
			
			
			var iConfirmLayer = function(){
				//弹出层插件的用法
				return $.layer({
					type: 1,
					title: false,
					closeBtn: false,
					shade : [0.5 , '#000' , true],
					border: [5, 0.5, '', true],
					area: ['310px','auto'],
					offset: [($(window).height()*0.3)+'px', ''],
					page: {
						html: viewContent
					},
					success: function(iLayer) {
						window.ontouchmove = stopDefaultAction;
						var eType = gconfig.triggerEventName;
						$x("pop_tip_confirm", "pop_tip_confirm_yes").off(eType);
						$x("pop_tip_confirm", "pop_tip_confirm_yes").on(eType, function() {
							try{layer.close(iAlertIdx);}catch(e){};
							p = -9999;
							if(yesFunc){ yesFunc(); }
						});
						$x("pop_tip_confirm", "pop_tip_confirm_no").off(eType);
						$x("pop_tip_confirm", "pop_tip_confirm_no").on(eType, function() {
							try{layer.close(iAlertIdx);}catch(e){};
							p = -9999;
							if(noFunc){ noFunc(); }
						});
						$("#pop_tip_confirm").css("margin-top","-"+($("#pop_tip_confirm").height()/2)+"px");
					},
					end: function() {window.ontouchmove = null;}
				});
			};
			if(iAlertIdx == -9999) { //如果没有iConfirm层
				iAlertIdx = iConfirmLayer();
			} else { //存在iConfirm层，先关闭前面那个iConfirm层，再弹出新的iConfirm层
				try{layer.close(iAlertIdx);}catch(e){};
				iAlertIdx = iConfirmLayer();
			}
	}
	
	// 自定义弹出层1
	function btnConfirmCrit(conMsg, yesFunc, noFunc, yesBtnWords, noBtnWords){
		    var iAlertIdx = -9999;
		    //弹出层的DIV的定义
			var viewContent ="<div class=\"backdrop\" style=\"display:block;\"></div>";
			viewContent +="<div class=\"pop_box pop_box02 pop_cancel pop\" id=\"pop_tip_confirm\" style=\"top:40%;display:block\">";
			viewContent += conMsg;
			viewContent +="    <div class=\"pop_footer\">";
			viewContent +="   	<div class=\"pop_btn02 two\">";
			viewContent +="  		<a class='ok' href=\"javascript:void(0);\" id=\"pop_tip_confirm_yes\">"+(yesBtnWords||"确 定")+"</a><a class='cancel' href=\"javascript:void(0);\" id=\"pop_tip_confirm_no\">"+(noBtnWords||"取消")+"</a>";
			viewContent +="     </div>";
			viewContent +="   </div>";
			viewContent +="</div>";
			var iConfirmLayer = function(){
				//弹出层插件的用法
				return $.layer({
					type: 1,
					title: false,
					closeBtn: false,
					shade : [0.5 , '#000' , true],
					border: [5, 0.5, '', true],
					area: ['310px','auto'],
					offset: [($(window).height()*0.3)+'px', ''],
					page: {
						html: viewContent
					},
					success: function(iLayer) {
						window.ontouchmove = stopDefaultAction;
						var eType = gconfig.triggerEventName;
						$x("pop_tip_confirm", "pop_tip_confirm_yes").off(eType);
						$x("pop_tip_confirm", "pop_tip_confirm_yes").on(eType, function() {
							try{layer.close(iAlertIdx);}catch(e){};
							p = -9999;
							if(yesFunc){ yesFunc(); }
						});
						$x("pop_tip_confirm", "pop_tip_confirm_no").off(eType);
						$x("pop_tip_confirm", "pop_tip_confirm_no").on(eType, function() {
							try{layer.close(iAlertIdx);}catch(e){};
							p = -9999;
							if(noFunc){ noFunc(); }
						});
						$("#pop_tip_confirm .close").off(eType);
						$("#pop_tip_confirm .close").on(eType, function() {
							try{layer.close(iAlertIdx);}catch(e){};
							p = -9999;
							if(noFunc){ noFunc(); }
						});
						$("#pop_tip_confirm").css("margin-top","-"+($("#pop_tip_confirm").height()/2)+"px");
					},
					end: function() {window.ontouchmove = null;}
				});
			};
			if(iAlertIdx == -9999) { //如果没有iConfirm层
				iAlertIdx = iConfirmLayer();
			} else { //存在iConfirm层，先关闭前面那个iConfirm层，再弹出新的iConfirm层
				try{layer.close(iAlertIdx);}catch(e){};
				iAlertIdx = iConfirmLayer();
			}
	}
	
	
	/**
	 * 阻止默认事件的行为
	 * @param e
	 */
	function stopDefaultAction(e)
	{
		if(e && e.preventDefault) {
			e.preventDefault();
		} else {
			window.event.returnValue = false;
		}
	}
	
	/**
     * 保存用户信息
     */
    function saveSessionUserInfo(userInfo, user_type){
    	var re_length = userInfo.length;
		var stock_json = {};
    	if (user_type === "0"){
    		appUtils.setSStorageInfo("stock_userInfo",JSON.stringify(userInfo[0]));
    		appUtils.setSStorageInfo("sz_account",userInfo[0].stock_account);
    		if(userInfo.length > 1){
    			//上海
    			appUtils.setSStorageInfo("sh_account",userInfo[1].stock_account);
    		}
    		for (var i = 0; i < re_length; i++){
    			var resu= userInfo[i];
    			stock_json[resu.exchange_type] = resu.stock_account;
    		}
    		appUtils.setSStorageInfo("stock_stockAccount", JSON.stringify(stock_json));//普通股东账号
    	} else {
    		appUtils.setSStorageInfo("credit_userInfo", JSON.stringify(userInfo[0]));
    		for (var i = 0; i < re_length; i++){
				var resu= userInfo[i];
				stock_json[resu.exchange_type] = resu.stock_account;
			}
			appUtils.setSStorageInfo("credit_stockAccount", JSON.stringify(stock_json));//信用股东账号
    	}
    	appUtils.setSStorageInfo("clientinfo", userInfo[0].clientinfo);
		appUtils.setSStorageInfo("jsessionid", userInfo[0].jsessionid);
		// 启动登录状态计时器
		apprPageBind();
    }
	
    /**
     * 删除用户信息
     */
    function clearSessionUserInfo()
    {
        appUtils.clearSStorage();
    }
       
    /**
     *处理模拟登陆失败
     */
	function ssoLoginFailed(data,pageCode)
    {
       //这里可以加一些逻辑处理，根据返回的错误号，目前，我这里默认处理是：弹出提示信息，跳到登陆页面
       //弹出提示信息，跳到登陆页面
       layerUtils.iAlert(data.error_info);
       require.async("sso",function(module){
            if(module.checkLoginRight())
            {
                module.goTologin(pageCode);
            }
        });
    }
	
	//隐藏底部导航栏
	function hideBottomBar(){
		if (gconfig.platform == "1"){
			external.callMessage({"funcNo": "50108", "moduleName": "main", "flag": "0"});
		} else if (gconfig.platform == "2") {
			external.callMessage({"funcNo": "50108", "moduleName": "system", "flag": "0"});
		}
	}
	
    var base = {
    	"bindStockEvent":bindStockEvent,
    	"numToMoneyType":numToMoneyType,
    	"filterLoginOut":filterLoginOut,
    	"firstLoadFunc" : firstLoadFunc,
    	"checkPermission":checkPermission,
    	"systemKeybord" :systemKeybord,
    	"getStockAccountListStr":getStockAccountListStr,
    	"initLogoutTime":initLogoutTime,
		"initStateTime":initStateTime,
		"clearStateTime":clearStateTime,
    	"decimalKeep":decimalKeep,
    	"appDownStop":appDownStop,
    	"loadCSS":loadCSS,
    	"btnConfirm":btnConfirm,
    	"getStockType":getStockType,
    	"saveSessionUserInfo": saveSessionUserInfo,
    	"clearSessionUserInfo": clearSessionUserInfo,
    	"ssoLoginFailed": ssoLoginFailed,
    	"hideBottomBar": hideBottomBar,
    	"btnConfirmCrit": btnConfirmCrit,
    	"decimalKeep1":decimalKeep1,
    	"apprPageBind": apprPageBind
    };

    module.exports = base;
});