/**
 * 基金service层调用接口
 */
define(function(require, exports, module) {
	var gconfig = require("gconfig");
	var appUtils = require("appUtils");
	var service = require("service");
	var global = gconfig.global;
	var serverPathTrade = global.serverPathTrade; //服务器URL
	var serviceSingleton = new service.Service();
	var external = require("external");
    
	function TradeService(){
	    this.serviceMap = {};
	}
	/********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo){
		reqParamVo.setReqParam(paraMap);
		ctrlParam = ctrlParam?ctrlParam:{};
		reqParamVo.setIsLastReq(ctrlParam.isLastReq);
		reqParamVo.setIsAsync(ctrlParam.isAsync);
		reqParamVo.setIsShowWait(ctrlParam.isShowWait);
		reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
		reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
		reqParamVo.setTipsWords(ctrlParam.tipsWords);
		reqParamVo.setDataType(ctrlParam.dataType);
		reqParamVo.setIsGlobal(ctrlParam.isGlobal);
		reqParamVo.setProtocol(ctrlParam.protocol);
		serviceSingleton.invoke(reqParamVo, callback);
	}

	function destroy(){
		serviceSingleton.destroy();
	}
	var service_fund = { //对应的接口方法需要在这里暴露出来
		"getInstance": getInstance, //为了避免以前调用getInstance方法报错
		"destroy": destroy
	};
	function getInstance(){
		return service_fund;
	}
	module.exports = service_fund;
	
	/********************************应用接口开始********************************/

	/**
	 * 添加OpStation
	 * */
	function addOpStation(param){
		var channelNo = " "; // 通道编号
		var ipAddr = " "; // ip 
		var macAddr = " "; // mac
		var hardId = " "; // 硬盘序列号（硬件id）
		var cpuId = " "; // cpu 序列号
		var mobileNo = " "; // 手机号
		var hardIdentifier = " "; //硬件特征码
		var source = " "; // 来源
		var other = " "; // 其他
 
		if(iBrowser.android){
			channelNo = "1";
		}else if(iBrowser.iPad || iBrowser.iPhone || iBrowser.ios){
			channelNo = "2";
		}else if(iBrowser.pc){
			channelNo = "0";
		}
		if(gconfig.platform != "0"){
			var external = require("external");
			var mobileNoInfo = external.callMessage({"funcNo":"50043","key":"mobilePhone"}); // 电话号码
			if(mobileNoInfo.error_no == "0"){
				mobileNo =mobileNoInfo.results[0].value;
			}
			var hardIdInfo = external.callMessage({"funcNo": "50022"}); //设备唯一码
			if(hardIdInfo.error_no ==  "0"){
				hardId = hardIdInfo.results[0].deviceToken;
			}
			var ipAddrInfo = external.callMessage({"funcNo": "50023"}); //设备IP地址
			if(ipAddrInfo.error_no ==  "0"){
				ipAddr = ipAddrInfo.results[0].ip;	
			}
			var macAddrInfo = external.callMessage({"funcNo": "50024"}); //设备MAC地址 
			if(macAddrInfo.error_no ==  "0"){
				macAddr = macAddrInfo.results[0].mac;
			}
			var versionInfo = external.callMessage({"funcNo": "50010"}); //应用版本号
			if(versionInfo.error_no ==  "0"){
				other = versionInfo.results[0].version;
			}
		}
		
		var aOpStation = [];
		aOpStation.push(channelNo);
		aOpStation.push("|");
		aOpStation.push(ipAddr);
		aOpStation.push("|");
		aOpStation.push(macAddr);
		aOpStation.push("|");
		aOpStation.push(hardId);
		aOpStation.push("|");
		aOpStation.push(cpuId);
		aOpStation.push("|");
		aOpStation.push(mobileNo);
		aOpStation.push("|");
		aOpStation.push(hardIdentifier);
		aOpStation.push("|");
		aOpStation.push(source);
		aOpStation.push("|");
		aOpStation.push(other);
		param.op_station = aOpStation.join(""); // 通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他
	}

	
	/********************************业务范围--基金********************************/
	 /**
	 * 基金账户信息查询
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * @param fund_company   基金公司
	 * */
	service_fund.getCustMsg = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302001";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	
	 /**
	 * 基金客户可购买基金查询
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * @param fund_company   基金公司
	 * */
	service_fund.queryCanSubscribe = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302002";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["fund_status"] = param.fund_status;
 		paraMap["fund_type"] = param.fund_type;
 		paraMap["fund_risklevel"] = param.fund_risklevel;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	
   /**
	 * 基金公司查询
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * @param fund_company   基金公司
	 * */
	service_fund.getFundCompany = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302004";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	  
	/**
	 * 基金详情查询
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param op_station    操作站点
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * */
	service_fund.getFundInfo = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302005";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 基金认购
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param amount        认购数量
	 * @param balance       认购金额
	 * @param flag          强制下单标志（0：否，1：是）
	 * */
	 service_fund.getSubScriptionBuy = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302006";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		paraMap["amount"] = param.amount;
		paraMap["balance"] = param.balance;
		paraMap["flag"] = param.flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 基金申购
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param sessionid      会话号
	 * @param fund_company   基金公司
	 * @param fund_code      基金代码
	 * @param auto_buy       分红方式
	 * @param balance        认购金额
	 * @param flag           强制下单标志（0：否，1：是）
	 * */
	 service_fund.getpurchaseBuy = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302007";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		paraMap["auto_buy"] = param.auto_buy;
		paraMap["balance"] = param.balance;
		paraMap["flag"] = param.flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 提交下单基金  基金赎回  
	 * @param funcNo              302008
	 * @param entrust_way         委托方式
	 * @param branch_no           分支机构
	 * @param fund_account        资金账号
	 * @param cust_code           客户编号
	 * @param password            密码
	 * @param op_station          操作站点
	 * @param sessionid           会话号
	 * @param fund_company        基金公司
	 * @param fund_code           基金代码
	 * @param amount              发生数量
	 * @param exceedflag          巨额赎回标志('0':取消，'1':顺延)
	 * */
	 service_fund.submitOrder = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302008";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["amount"] = param.amount;
 		paraMap["exceedflag"] = param.exceedflag;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 基金撤单
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param begin_date    起始日期
	 * @param end_date      截止日期
	 * @param business_flag 业务类别
	 * */
	 service_fund.cancelOrder = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302009";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["allot_date"] = param.allot_date;
		paraMap["entrust_no"] = param.entrust_no;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 当日基金委托查询
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param business_flag 业务类别
	 * */
	service_fund.queryTodayTrust = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302011";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		paraMap["business_flag"] = param.business_flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 基金持仓查询,基金份额查询
	 * @param callback      回调函数	
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * */
	 service_fund.queryFundData = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302012";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 基金当日成交查询
	 * @param callback      回调函数	
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * */
	 service_fund.queryTodayTrade = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302013";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 历史基金委托查询
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param begin_date    起始日期
	 * @param end_date      截止日期
	 * @param business_flag 业务类别
	 * */
	 service_fund.queryHistoryTrust = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302014";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		paraMap["business_flag"] = param.business_flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 历史基金成交查询
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param begin_date    起始日期
	 * @param end_date      截止日期
	 * */
	 service_fund.queryHistoryTrade = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302015";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_company"] = param.fund_company;
		paraMap["fund_code"] = param.fund_code;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		paraMap["business_flag"] = param.business_flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 基金开户
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param flag          是否首次开户（0：否，1：是）
	 * */
	 service_fund.openFundAccount = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302030";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["password"] = param.password;
		paraMap["fund_company"] = param.fund_company;
		paraMap["stock_account"] = param.stock_account;
		paraMap["flag"] = param.flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 风险测评问卷查询
	 * @param callback      回调函数
	 * @param entrust_way   委托方试
	 * @param branch_no     分支机构
	 * @param sessionid     会话号
	 * @param fund_company  基金公司
	 * @param fund_code     基金代码
	 * @param flag          是否首次开户（0：否，1：是）
	 * */
	 service_fund.queryRiskQuestions = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "300105";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["password"] = param.password;
		paraMap["risk_kind"] = param.risk_kind;
		paraMap["organ_flag"] = param.organ_flag;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 风险测评问卷提交
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * @param risk_kind   风险问卷类型（见数据字典）
	 * @param paper_answer   提交答案
	 * */
	service_fund.submitCustAnswer = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "300106";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["risk_kind"] = param.risk_kind;
 		paraMap["paper_answer"] = param.paper_answer;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	
	/**
	 * 基金当日可撤委托信息查询
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * */
	service_fund.queryTodayCancel = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302019";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["op_station"] = param.op_station;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["business_flag"] = param.business_flag;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	//10014242 123321
	/**
	 * 基金委托撤单
	 * @param callback       回调函数
	 * @param entrust_way    委托方试
	 * @param branch_no      分支机构
	 * @param op_station     操作站点
	 * @param sessionid      会话号
	 * */
	service_fund.cancelFundEntrust = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302009";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["op_station"] = param.op_station;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["allot_date"] = param.allot_date;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["entrust_no"] = param.entrust_no;
 		paraMap["fund_company"] = param.fund_company;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	
	//判断是否开户
	service_fund.openFundAccount = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302053";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	//判断是否做过风险测评
	service_fund.riskAssessment = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302052";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	
	/**
	 * 基金开户(开户时的信息从系统中查询获取）
	 */
	service_fund.fundAccount = function(param, callback, ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "302030";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["stock_account"] = param.stock_account;
 		paraMap["flag"] = param.flag;
 		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};  
	
	//开放式基金筛选条件查询
	service_fund.queryDisparkFund = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302054";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["type"] = param.type;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金份额查询
	service_fund.queryFundShareOutBonus = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302012";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金分红方式设置
	service_fund.shareOutBonusSetting = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302016";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["dividendmethod"] = param.dividendmethod;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金定投查询
	service_fund.queryFundCastSurely = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302051";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金定投撤销
	service_fund.fundUndo = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302050";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["stock_account"] = param.stock_account;
 		paraMap["allotno"] = param.allotno;
 		paraMap["fund_company"] = param.fund_company;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["en_fund_date"] = param.en_fund_date;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金查询定时定额种类设置（用于定投）<扣款日查询>
	service_fund.queryReimbursementDate = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302057";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["save_plan_cls"] = param.save_plan_cls;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金定投修改
	service_fund.fundCastSurelyModify = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302049";
		paraMap["entrust_way"] = param.entrust_way;
 		paraMap["branch_no"] = param.branch_no;
 		paraMap["fund_account"] = param.fund_account;
 		paraMap["cust_code"] = param.cust_code;
 		paraMap["password"] = param.password;
 		paraMap["sessionid"] = param.sessionid;
 		paraMap["fund_code"] = param.fund_code;
 		paraMap["balance"] = param.balance;
 		paraMap["start_date"] = param.start_date;
 		paraMap["end_date"] = param.end_date;
 		paraMap["en_fund_date"] = param.en_fund_date;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//查询基金风险测评查询结果
	service_fund.queryRiskAssessmentResult = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "300104";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["risk_kind"] = param.risk_kind;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	
	//基金拆分与合并的数据查询
	service_fund.querySplitCombineData = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302056";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["fund_opertype"] = param.fund_opertype;
		paraMap["fund_code"] = param.fund_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	//基金拆分与合并
	service_fund.splitCombineSubmit = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "302055";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_account"] = param.stock_account;
		paraMap["fund_code"] = param.fund_code;
		paraMap["fund_opertype"] = param.fund_opertype;
		paraMap["entrust_amount"] = param.entrust_amount;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();;
		reqParamVo.setUrl(global.serverPathTrade);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/***应用接口......................................................结束*/

});