/**
 * 港股通service层调用接口
 */
define(function(require, exports, module) {

	var gconfig = require("gconfig");
	var appUtils = require("appUtils");
	var service = require("service");
	var global = gconfig.global;
	var serverPathTrade = global.serverPathTrade; //服务器URL
	var serviceSingleton = new service.Service();
	var external = require("external");
    
	/********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo){
		reqParamVo.setReqParam(paraMap);
		ctrlParam = ctrlParam?ctrlParam:{};
		reqParamVo.setIsLastReq(ctrlParam.isLastReq);
		reqParamVo.setIsAsync(ctrlParam.isAsync);
		reqParamVo.setIsShowWait(ctrlParam.isShowWait);
		reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
		reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
		reqParamVo.setTipsWords(ctrlParam.tipsWords);
		reqParamVo.setDataType(ctrlParam.dataType);
		reqParamVo.setIsGlobal(ctrlParam.isGlobal);
		reqParamVo.setProtocol(ctrlParam.protocol);
		serviceSingleton.invoke(reqParamVo, callback);
	}

	function destroy(){
		serviceSingleton.destroy();
	}
	var service_ggt = { //对应的接口方法需要在这里暴露出来
		"getInstance": getInstance, //为了避免以前调用getInstance方法报错
		"destroy": destroy
	};
	function getInstance(){
		return service_ggt;
	}
	module.exports = service_ggt;
	
	/********************************应用接口开始********************************/

	/**
	 * 添加OpStation
	 * */
	function addOpStation(param){
		var channelNo = " "; // 通道编号
		var ipAddr = " "; // ip 
		var macAddr = " "; // mac
		var hardId = " "; // 硬盘序列号（硬件id）
		var cpuId = " "; // cpu 序列号
		var mobileNo = " "; // 手机号
		var hardIdentifier = " "; //硬件特征码
		var source = " "; // 来源
		var other = " "; // 其他
 
		if(iBrowser.android){
			channelNo = "1";
		}else if(iBrowser.iPad || iBrowser.iPhone || iBrowser.ios){
			channelNo = "2";
		}else if(iBrowser.pc){
			channelNo = "0";
		}
		if(gconfig.platform != "0"){
			var external = require("external");
			var mobileNoInfo = external.callMessage({"funcNo":"50043","key":"mobilePhone"}); // 电话号码
			if(mobileNoInfo.error_no == "0"){
				mobileNo =mobileNoInfo.results[0].value;
			}
			var hardIdInfo = external.callMessage({"funcNo": "50022"}); //设备唯一码
			if(hardIdInfo.error_no ==  "0"){
				hardId = hardIdInfo.results[0].deviceToken;
			}
			var ipAddrInfo = external.callMessage({"funcNo": "50023"}); //设备IP地址
			if(ipAddrInfo.error_no ==  "0"){
				ipAddr = ipAddrInfo.results[0].ip;	
			}
			var macAddrInfo = external.callMessage({"funcNo": "50024"}); //设备MAC地址 
			if(macAddrInfo.error_no ==  "0"){
				macAddr = macAddrInfo.results[0].mac;
			}
			var versionInfo = external.callMessage({"funcNo": "50010"}); //应用版本号
			if(versionInfo.error_no ==  "0"){
				other = versionInfo.results[0].version;
			}
		}
		
		var aOpStation = [];
		aOpStation.push(channelNo);
		aOpStation.push("|");
		aOpStation.push(ipAddr);
		aOpStation.push("|");
		aOpStation.push(macAddr);
		aOpStation.push("|");
		aOpStation.push(hardId);
		aOpStation.push("|");
		aOpStation.push(cpuId);
		aOpStation.push("|");
		aOpStation.push(mobileNo);
		aOpStation.push("|");
		aOpStation.push(hardIdentifier);
		aOpStation.push("|");
		aOpStation.push(source);
		aOpStation.push("|");
		aOpStation.push(other);
		param.op_station = aOpStation.join(""); // 通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他
	}

	/********************************业务范围--港股通********************************/
        
	   /**
	  	 * 港股通行情查询
	     * @param {Object} exchange_type            交易市场类别
	     * @param {Object} stock_code               证券代码
	     * */
     	 service_ggt.queryHq_ggt=function(param,callback,ctrlParam){
     		var paraMap = {};
     		paraMap["funcNo"] = "301600";
     		paraMap["exchange_type"] = param.entrust_way;
     		paraMap["stock_code"] =  param.stock_code;
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
	   /**
	  	 * 港股通额度查询
	     * @param {Object} exchange_type            交易市场类别
	     * */
     	 service_ggt.queryAvailable_ggt=function(param,callback,ctrlParam){
     		var paraMap = {};
     		paraMap["funcNo"] = "301601";
     		paraMap["exchange_type"] = param.entrust_way;
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
	   /**
    	 * 港股通股票联动
    	 * @param {Object} entrust_way              委托方式
      	 * @param {Object} branch_no                分支机构
      	 * @param {Object} fund_account             资金账号
      	 * @param {Object} cust_code                客户编号
      	 * @param {Object} password                	交易密码
      	 * @param {Object} sessionid                会话号
       	 * @param {Object} entrust_bs               买卖方向
      	 * @param {Object} stock_code               股票号码
       	 * @param {Object} entrust_price            委托价格
    	 * @param {Object} callback	回调方法
    	 * */
     	 service_ggt.queryInformation_ggt=function(param,callback,ctrlParam){
     		var paraMap = {};
     		paraMap["funcNo"] = "301602";
      	    paraMap["entrust_way"] = param.entrust_way;
    	    paraMap["branch_no"] =  param.branch_no;
    	    paraMap["fund_account"] = param.fund_account;
    	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["entrust_bs"] = param.entrust_bs;
    	    paraMap["stock_code"] =  param.stock_code;
    	    paraMap["entrust_price"] = param.entrust_price;
    	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
	   /**
    	 * 港股通委托确认
    	 * @param {Object} entrust_way              委托方式
      	 * @param {Object} branch_no                分支机构
      	 * @param {Object} fund_account             资金账号
      	 * @param {Object} cust_code                客户编号
      	 * @param {Object} password                	交易密码
      	 * @param {Object} sessionid                会话号
       	 * @param {Object} entrust_bs               买卖方向
      	 * @param {Object} stock_code               股票号码
       	 * @param {Object} entrust_price            委托价格
       	 * @param {Object} single_flag              是否零股申报（0：否，1：是)
       	 * @param {Object} max_price_levels         最大价格等级(1:表示竞价限价盘 0:表示增强限价盘)
    	 * @param {Object} callback	回调方法
    	 * */
     	 service_ggt.queryTrustSure_ggt=function(param,callback,ctrlParam){
     		var paraMap = {};
     		paraMap["funcNo"] = "301603";
      	    paraMap["entrust_way"] = param.entrust_way;
    	    paraMap["branch_no"] =  param.branch_no;
    	    paraMap["fund_account"] = param.fund_account;
    	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["entrust_bs"] = param.entrust_bs;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
    	    paraMap["entrust_price"] = param.entrust_price;
    	    paraMap["entrust_amount"] =  param.entrust_amount;
    	    paraMap["single_flag"] =  param.single_flag;
    	    paraMap["max_price_levels"] =  param.max_price_levels;
    	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
    	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
    	/**
    	 * 港股通委托撤单
  	     * @param {Object} entrust_way              委托方式
    	 * @param {Object} branch_no                分支机构
    	 * @param {Object} fund_account             资金账号
    	 * @param {Object} cust_code                客户编号
    	 * @param {Object} password                	交易密码
    	 * @param {Object} sessionid                会话号
     	 * @param {Object} entrust_no               委托编号
    	 * @param {Object} exchange_type            交易类别
     	 * @param {Object} batch_flag            	批量撤单标志
    	 * @param {Object} callback	回调方法
    	 * */
         service_ggt.postCancelOrder_ggt=function(param,callback,ctrlParam){
    		var paraMap = {};
    	    paraMap["funcNo"] = "301604";
    	    paraMap["entrust_way"] = param.entrust_way;
	  	    paraMap["branch_no"] =  param.branch_no;
	  	    paraMap["fund_account"] = param.fund_account;
	  	    paraMap["cust_code"] =  param.cust_code;
	  	    paraMap["password"] = param.password;
	  	    paraMap["sessionid"] =  param.sessionid;
	  	    paraMap["entrust_no"] = param.entrust_no;
	  	    paraMap["batch_flag"] =  param.batch_flag;
	  	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    	};
    	
 	    /**
    	 * 港股通持仓查询
    	 * @param {Object} entrust_way              委托方式
      	 * @param {Object} branch_no                分支机构
      	 * @param {Object} fund_account             资金账号
      	 * @param {Object} cust_code                客户编号
      	 * @param {Object} password                	交易密码
      	 * @param {Object} sessionid                会话号
       	 * @param {Object} entrust_bs               买卖方向
      	 * @param {Object} stock_code               股票号码
    	 * @param {Object} callback	回调方法
    	 * */
     	 service_ggt.queryHolding_ggt=function(param,callback,ctrlParam){
     		var paraMap = {};
     		paraMap["funcNo"] = "301605";
      	    paraMap["entrust_way"] = param.entrust_way;
    	    paraMap["branch_no"] =  param.branch_no;
    	    paraMap["fund_account"] = param.fund_account;
    	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
    	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
    	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
       /**
		 * 港股通当日委托查询 
		 * @param {Object} entrust_way              委托方式
		 * @param {Object} branch_no                分支机构
		 * @param {Object} fund_account             资金账号
		 * @param {Object} cust_code                客户编号
		 * @param {Object} sessionid                会话号
		 * @param {Object} exchange_type            交易市场类别
		 * @param {Object} stock_account            证券账号
		 * @param {Object} stock_code               证券代码
		 * @param {Object} entrust_bs               委托标志
		 * */
		 service_ggt.queryTodayTrust_ggt=function(param,callback,ctrlParam){
			var paraMap = {};
		    paraMap["funcNo"] = "301606";
		    paraMap["entrust_way"] = param.entrust_way;
		    paraMap["branch_no"] =  param.branch_no;
		    paraMap["fund_account"] = param.fund_account;
		    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
    	    paraMap["entrust_bs"] =  param.entrust_bs;
		    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		    var reqParamVo = new service.ReqParamVo();
			reqParamVo.setUrl(global.serverPathTrade);
			commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};
		
		/**
		 * 港股通当日成交查询
		 * @param {Object} entrust_way              委托方式
		 * @param {Object} branch_no                分支机构
		 * @param {Object} fund_account             资金账号
		 * @param {Object} cust_code                客户编号
		 * @param {Object} sessionid                会话号
		 * @param {Object} exchange_type            交易市场类别
		 * @param {Object} stock_account            证券账号
		 * @param {Object} stock_code               证券代码
		 * @param {Object} entrust_bs               委托标志
		 * @param {Object} callback	回调方法
		 * */
		 service_ggt.queryTodayTrade_ggt=function(param,callback,ctrlParam){
			var paraMap = {};
		    paraMap["funcNo"] = "301607";
		    paraMap["entrust_way"] = param.entrust_way;
			paraMap["branch_no"] =  param.branch_no;
		    paraMap["fund_account"] = param.fund_account;
			paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
    	    paraMap["entrust_bs"] =  param.entrust_bs;
			addOpStation(paraMap); // 添加 op_station 到接口请求参数中
			var reqParamVo = new service.ReqParamVo();
			reqParamVo.setUrl(global.serverPathTrade);
			commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
		};

       /**
    	 * 港股通历史委托查询
    	 * 
  	     * @param {Object} entrust_way              委托方式
    	 * @param {Object} branch_no                分支机构
    	 * @param {Object} fund_account             资金账号
    	 * @param {Object} cust_code                客户编号
    	 * @param {Object} sessionid                会话号
    	 * @param {Object} begin_time               开始日期
    	 * @param {Object} end_time                	截止日期
    	 * @param {Object} exchange_type            交易市场类别
		 * @param {Object} stock_account            证券账号
		 * @param {Object} stock_code               证券代码
		 * @param {Object} entrust_bs               委托标志
    	 * */
         service_ggt.queryHistoryTrust_ggt=function(param,callback,ctrlParam){
    		var paraMap = {};
    	    paraMap["funcNo"] = "301608";
    	    paraMap["entrust_way"] = param.entrust_way;
	  	    paraMap["branch_no"] =  param.branch_no;
	  	    paraMap["fund_account"] = param.fund_account;
	  	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
	  	    paraMap["begin_time"] =  param.begin_time;
	  	    paraMap["end_time"] =  param.end_time;
	  		paraMap["entrust_bs"] = param.entrust_bs;
	  		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    	};
    	
    	/**
    	 * 港股通历史成交查询
    	 * 
  	     * @param {Object} entrust_way              委托方式
    	 * @param {Object} branch_no                分支机构
    	 * @param {Object} fund_account             资金账号
    	 * @param {Object} cust_code                客户编号
    	 * @param {Object} sessionid                会话号
    	 * @param {Object} begin_time               开始日期
    	 * @param {Object} end_time                	截止日期
    	 * @param {Object} exchange_type            交易市场类别
		 * @param {Object} stock_account            证券账号
		 * @param {Object} stock_code               证券代码
		 * @param {Object} entrust_bs               委托标志
    	 * @param {Object} callback	回调方法
    	 * */
         service_ggt.queryHistoryTrade_ggt=function(param,callback,ctrlParam){
    		var paraMap = {};
    	    paraMap["funcNo"] = "301609";
    	    paraMap["entrust_way"] = param.entrust_way;
	  	    paraMap["branch_no"] =  param.branch_no;
	  	    paraMap["fund_account"] = param.fund_account;
	  	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
	  	    paraMap["begin_time"] =  param.begin_time;
	  	    paraMap["end_time"] =  param.end_time;
	  		paraMap["entrust_bs"] = param.entrust_bs;
	  		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    	};
    	
    	/**
         * 港股通当日可撤委托查询
  	     * @param {Object} entrust_way              委托方式
    	 * @param {Object} branch_no                分支机构
    	 * @param {Object} fund_account             资金账号
    	 * @param {Object} cust_code                客户编号
    	 * @param {Object} sessionid                会话号
    	 * @param {Object} exchange_type            交易市场类别
		 * @param {Object} stock_account            证券账号
		 * @param {Object} stock_code               证券代码
		 * @param {Object} entrust_bs               委托标志
    	 * */
         service_ggt.queryTodayTrusts_ggt=function(param,callback,ctrlParam){
    		var paraMap = {};
    	    paraMap["funcNo"] = "301610";
    	    paraMap["entrust_way"] = param.entrust_way;
	  	    paraMap["branch_no"] =  param.branch_no;
	  	    paraMap["fund_account"] = param.fund_account;
	  	    paraMap["cust_code"] =  param.cust_code;
	  	    paraMap["cust_code"] =  param.cust_code;
    	    paraMap["password"] = param.password;
    	    paraMap["sessionid"] =  param.sessionid;
    	    paraMap["exchange_type"] =  param.exchange_type;
    	    paraMap["stock_account"] = param.stock_account;
    	    paraMap["stock_code"] =  param.stock_code;
    	    paraMap["entrust_bs"] = param.entrust_bs;
	  	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
	  	    var reqParamVo = new service.ReqParamVo();
	  		reqParamVo.setUrl(global.serverPathTrade);
	  		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    	};
    	
      	/**
      	 * 资金查询
      	 * 
    	 * @param {Object} entrust_way              委托方式
      	 * @param {Object} branch_no                分支机构
      	 * @param {Object} fund_account             资金账号
      	 * @param {Object} cust_code                客户编号
      	 * @param {Object} sessionid                会话号
      	 * @param {Object} callback	回调方法
      	 * @param {Object} isLastReq	是否是最后一个请求，默认是true	
      	 * */
    	service_ggt.queryFundSelect_ggt=function(param,callback,ctrlParam){
      		var paraMap = {};
      	    paraMap["funcNo"] = "301612";
      	    paraMap["entrust_way"] =  param.entrust_way;
      	    paraMap["branch_no"] =  param.branch_no;
      	    paraMap["fund_account"] =  param.fund_account;
      	    paraMap["cust_code"] =  param.cust_code;
      	    paraMap["password"] =  param.password;
      	    paraMap["sessionid"] =  param.sessionid;
      	    paraMap["money_type"] =  param.money_type;
      	    addOpStation(paraMap); // 添加 op_station 到接口请求参数中
    		var reqParamVo = new service.ReqParamVo();
    		reqParamVo.setUrl(global.serverPathTrade);
    		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      	};

	/***应用接口......................................................结束*/

});