/**
 * 手机前端service层调用接口
 **/
define(function(require,exports,module){
	var appUtils = require("appUtils");
	var gconfig = require("gconfig");
	var global = gconfig.global;
	var url = global.serverPath;
	var service = require("service");
	var serviceSingleton = new service.Service();
	var nativePluginService = require("nativePluginService");
	
	/********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo){
		reqParamVo.setReqParam(paraMap);
		ctrlParam = ctrlParam?ctrlParam:{};
		reqParamVo.setIsLastReq(ctrlParam.isLastReq);
		reqParamVo.setIsAsync(ctrlParam.isAsync);
		reqParamVo.setIsShowWait(ctrlParam.isShowWait);
		reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
		reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
		reqParamVo.setTipsWords(ctrlParam.tipsWords);
		reqParamVo.setDataType(ctrlParam.dataType);
		reqParamVo.setIsGlobal(ctrlParam.isGlobal);
		reqParamVo.setProtocol(ctrlParam.protocol);
		reqParamVo.setUrl(setSessionUrl());
		serviceSingleton.invoke(reqParamVo, callback);
	}
	function destroy(){
		serviceSingleton.destroy();
	}
	var mobileService = { //对应的接口方法需要在这里暴露出来
		"getInstance": getInstance, //为了避免以前调用getInstance方法报错
		"destroy": destroy
	};
	function getInstance(){
		return mobileService;
	}
	module.exports = mobileService;

	function setSessionUrl(){
		if(appUtils.getSStorageInfo("jsessionid") && url.indexOf(";jsessionid=")<0) {
			url = url + ";jsessionid=" + appUtils.getSStorageInfo("jsessionid");
		}
		return url;
	}

	/********************************应用接口开始********************************/

	/**
	 * 添加OpStation
	 * */
	function addOpStation(param){

		var channelNo = " "; // 通道编号
		var ipAddr = " "; // ip
		var macAddr = " "; // mac
		var hardId = " "; // 硬盘序列号（硬件id）
		var cpuId = " "; // cpu 序列号
		var mobileNo = " "; // 手机号
		var hardIdentifier = " "; //硬件特征码
		var source = " "; // 来源
		var other = " "; // 其他

		if(iBrowser.android){
			channelNo = "1";
		}else if(iBrowser.iPad || iBrowser.iPhone || iBrowser.ios){
			channelNo = "2";
		}else if(iBrowser.pc){
			channelNo = "0";
		}
		if(gconfig.platform != "0"){
			var external = require("external");
			mobileNo = appUtils.getSStorageInfo("mobile");
            if(!mobileNo || mobileNo.length == 0){
                var mobileNoInfo = external.callMessage({"funcNo":"50043","key":"mobilePhone"}); // 电话号码
                if(mobileNoInfo.error_no == "0"){
                    mobileNo = mobileNoInfo.results[0].value;
                    appUtils.setSStorageInfo("mobilePhone",mobileNo);
                }
            }
            hardId = appUtils.getSStorageInfo("hardId");
            if(!hardId || hardId.length == 0){
                var hardIdInfo = external.callMessage({"funcNo": "50022"}); //设备唯一码
                if(hardIdInfo.error_no ==  "0"){
                    hardId = hardIdInfo.results[0].deviceToken;
                    appUtils.setSStorageInfo("hardId",hardId);
                }
            }
            ipAddr = appUtils.getSStorageInfo("ipAddr");
            if(!ipAddr || ipAddr.length == 0){
                var ipAddrInfo = external.callMessage({"funcNo": "50023"}); //设备IP地址
                if(ipAddrInfo.error_no ==  "0"){
                    ipAddr = ipAddrInfo.results[0].ip;
                    appUtils.setSStorageInfo("ipAddr",ipAddr);
                }
            }
			macAddr = appUtils.getSStorageInfo("macAddr");
            if(!macAddr || macAddr.length == 0){
                var macAddrInfo = external.callMessage({"funcNo": "50024"}); //设备MAC地址
                if(macAddrInfo.error_no ==  "0"){
                    macAddr = macAddrInfo.results[0].mac;
                    appUtils.setSStorageInfo("macAddr",macAddr);
                }
            }
            other = appUtils.getSStorageInfo("other");
            if(!other || other.length == 0){
                var versionInfo = external.callMessage({"funcNo": "50010"}); //应用版本号
                if(versionInfo.error_no ==  "0"){
                    other = versionInfo.results[0].version;
                    appUtils.setSStorageInfo("other",other);
                }
            }
		}
		var aOpStation = [];
		aOpStation.push(channelNo);
		aOpStation.push("|");
		aOpStation.push(ipAddr);
		aOpStation.push("|");
		aOpStation.push(macAddr);
		aOpStation.push("|");
		aOpStation.push(hardId);
		aOpStation.push("|");
		aOpStation.push(cpuId);
		aOpStation.push("|");
		aOpStation.push(mobileNo);
		aOpStation.push("|");
		aOpStation.push(hardIdentifier);
		aOpStation.push("|");
		aOpStation.push(source);
		aOpStation.push("|");
		aOpStation.push(other);

		var tab_type = appUtils.getSStorageInfo("tab_type");						//普通账号：stock 两融：credit
		var client_id = "";
		if(gconfig.platform != "0"){
			var external = require("external");
			if("stock_tab" == tab_type){
				client_id = external.callMessage({"key":"client_id","funcNo": "50041"}).results[0].value;
			}else if("credit_tab" == tab_type){
				client_id = external.callMessage({"key":"credit_client_id","funcNo": "50041"}).results[0].value;
			}
		}
		param.op_station = aOpStation.join(""); // 通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他
		param.custid = client_id; 			// 客户号
//		param.op_station = "1|2|2|2|2|2|2|2|2|2|2|2|2"; // 通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他
//      param.custid = "10050204";
	}

	/**
	 * 接口方法模板
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitPhoto = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "501503";
		paraMap["user_id"] = param.user_id;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台登陆接口
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.login = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1000";
		paraMap["login_id"] = param.login_id;
		paraMap["identity_num"] = param.identity_num;
		paraMap["pwd_type"] = param.pwd_type;
		paraMap["pwd_value"] = param.pwd_value;
		paraMap["login_uid"] = param.login_uid;
		paraMap["login_type"] = param.login_type;
		paraMap["account_type"] = param.account_type;
		paraMap["op_source"] = "3";

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台同步用户交易帐号
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.syncTradeAccount = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|获取沪港通需要判断的账户条件
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtAuthority = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004200";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["isbind"] = param.isbind;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|获取沪港通业务数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004201";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|获取风险评测结果
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSurveyInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004196";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["sub_id"] = param.sub_id;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|获取风险评测结果
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSurveyQuestion = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004138";
		paraMap["user_id"] = param.user_id;
		paraMap["subject_code"] = param.subject_code;
		paraMap["business_code"] = param.business_code;
		paraMap["business_id"] = param.business_id;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|获取电子协议
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004178";
		paraMap["agree_name"] = param.category_englishname;
		paraMap["type_code"] = param.category_no;
		paraMap["agree_no"] = param.econtract_no;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|获取电子协议内容
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getProtocolInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004179";
		paraMap["version"] = param.version;
		paraMap["agree_no"] = param.agree_no;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|验签，修改签名标识状态
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.checkSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004206";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["sign_source_flag"] = param.sign_source_flag;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|获取业务办理过程中的所有步骤的数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getGgtAllInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004207";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|查询信用资产
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getNetInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004405";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["password"] = param.password;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 沪港通|提交问卷
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitTestAnswer = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004139";
		paraMap["user_id"] = param.user_id;
		paraMap["subject_code"] = param.subject_code;
		paraMap["answerStr"] = param.answerStr;
		paraMap["need_third"] = param.need_third;
		paraMap["question_source"] = param.question_source;
		paraMap["sub_id"] = param.sub_id;
		paraMap["fundid"] = param.fundid;
		paraMap["business_code"] = param.business_code;
		paraMap["business_id"] = param.business_id;
		paraMap["subject_type"] = param.subject_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|发送短信
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.sendSmsCode = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004181";
		paraMap["user_id"] = param.user_id;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["sms_type"] = param.sms_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 通用|短信验证
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.checkSmsCode = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004191";
		paraMap["mobile_code"] = param.mobile_code;
		paraMap["mobile"] = param.mobile;
		paraMap["sms_type"] = param.sms_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 用户体系|短信修改手机号码
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitMobileNo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1007";
		paraMap["user_id"] = param.user_id;
		paraMap["mobile_code"] = param.mobile_code;
		paraMap["old_mobile"] = param.old_mobile;
		paraMap["new_mobile"] = param.new_mobile;
		paraMap["fundid"] = param.fundid;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|获取深A和创业板权限开通数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getCybInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004020";
		paraMap["user_id"] = param.user_id;
		paraMap["isbind"] = param.isbind;
		paraMap["fundid"] = param.fundid;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	
	/**
	 * 创业板|查询创业板转签办理状态
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getCybStatus = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004021";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
	
	/**
	 * 创业板|修改“是否需要创业板转签”标识
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.alterCybSign = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004022";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 创业板|提交创业板转签请求
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.submitCyb = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004023";
		paraMap["user_id"] = param.user_id;
		paraMap["name"] = param.name;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["trdaccount"] = param.trdaccount;
		paraMap["relation"] = param.relation;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

    /**
	 * 创业板|创业板开通，提交紧急联系人信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.openCyb = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004027";
		paraMap["user_id"] = param.user_id;
		paraMap["name"] = param.name;
		paraMap["mobile_no"] = param.mobile_no;
		paraMap["trdaccount"] = param.trdaccount;
		paraMap["relation"] = param.relation;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}
	
	/**
	 * 云柜台|根据资金账户获取绑定的银行卡
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.getBankList = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004134";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["flag_status"] = param.flag_status;
		paraMap["account_type"] = param.account_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	
	/**
	 * 云柜台|根据资金账户获取绑定的银行卡
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getAllBankList = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004135";
		paraMap["business_code"] = param.business_code;
		paraMap["bindtype"] = param.bindtype;
		paraMap["ispwd"] = param.ispwd;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }
	 
	 /**
	 * 云柜台|将银行卡和资金账号绑定
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.bindBank = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004136";
		paraMap["user_id"] = param.user_id;
		paraMap["backCardId"] = param.backCardId;
		paraMap["cardNo"] = param.cardNo;
		paraMap["cardPassword"] = param.cardPassword;
		paraMap["zj_account"] = param.zj_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|电子协议签署验签
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.checkSignProtocol = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004185";
		paraMap["user_id"] = param.user_id;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["business_code"] = param.business_code;
		paraMap["business_item"] = param.business_item;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		paraMap["certType"] = param.certType;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|三方存管-充值/提现
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.handleMoney = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004149";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["bankNum"] = param.bankNum;
		paraMap["money"] = param.money;
		paraMap["password"] = param.password;
		paraMap["flag"] = param.flag;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|获取委托方式
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getDelegate = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004151";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
	 
	 /**
	 * 云柜台|修改委托方式
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.editDelegate = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004161";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["change_type"] = param.change_type;
		paraMap["entrust_code"] = param.entrust_code;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	 
	 /**
	 * 云柜台|获取三方存管、风险测评、证件照片、委托方式相关信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getRsikInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004163";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 }
		 
	 /**
	 * 云柜台|查询资产信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.queryAssetInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004142";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	
	 /**
	 * 云柜台|查询用户的所有交易帐号信息
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户编号
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.queryTradeInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004140";
		paraMap["user_id"] = param.user_id;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	 	
	 /**
   	 * 获取rsa加密模块和公钥
   	 * @param param  参数
   	 * @param callback 回调函数
   	 */
	 mobileService.getRSAKey = function(param,callback,ctrlParam)
    {
	    var paraMap = {};
		paraMap["funcNo"] = "1000000";

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
    
	 /**
	 * 云柜台|修改资金密码
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户编号
	 * @param zj_account 资金账号
	 * @param oldPassword 旧资金密码
	 * @Param zj_password 新资金密码
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.modifyFundPwd = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004162";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["oldPassword"] = param.oldPassword;
		paraMap["zj_password"] = param.zj_password;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	 
	 /**
	 * 云柜台|修改交易密码
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户编号
	 * @param zj_account 资金账号
	 * @param oldPassword 旧交易密码
	 * @Param jy_password 新交易密码
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.modifyTradePwd = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004133";
		paraMap["user_id"] = param.user_id;
		paraMap["zj_account"] = param.zj_account;
		paraMap["oldPassword"] = param.oldPassword;
		paraMap["jy_password"] = param.jy_password;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	 
	 /**
	 * 云柜台|查询数据字典
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param enum_type 数据字典类型
	 * @param item_name 数据字典具体字段名
	 * @param item_value 数据字典value
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.queryFundation = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004169";
		paraMap["enum_type"] = param.enum_type;
		paraMap["item_name"] = param.item_name;
		paraMap["item_value"] = param.item_value;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	 
	 /**
	 * 云柜台|查询用户已开通的权限
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户ID
	 * @param fundid 资金帐号
	 * @param agmt_type_str 需要查询的协议类型,多个用_下划线分开
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.queryOpenLimit = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004429";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["agmt_type_str"] = param.agmt_type_str;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };

	 /**
	 * 创业板|获取创业板开通业务办理数据
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户ID
	 * @param trdaccount 深A帐号
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.getCybBusiness = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004024";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	
		 
	 /**
	 * 沪港通|调用第三方接口 获取测评题目
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param user_id 用户ID
	 * @param fundid 资金帐号
	 * @param sub_id 第三方问卷id(调查表编号) 1：风险测评，3：沪港通业务知识测评
	 * @param sno 大标题序号 -1查询全部 1为风险问卷 2：沪港通适当性测评
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	 mobileService.queryRiskInfo = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004197";
		paraMap["user_id"] = param.user_id;
		paraMap["fundid"] = param.fundid;
		paraMap["sub_id"] = param.sub_id;
		paraMap["sno"] = param.sno;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	 };
	
	 /**
	 * 沪港通|添加沪港通跑批任务
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.openAccount = function(param,callback,ctrlParam) {
	    var paraMap = {};
		paraMap["funcNo"] = "1004205";
		paraMap["user_id"] = param.user_id;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

	 /**
	 * 沪港通|修改问卷流程状态
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.modifyQuesStep = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004202";
		paraMap["user_id"] = param.user_id;
		paraMap["survey_type"] = param.survey_type;
		paraMap["trdaccount"] = param.trdaccount;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	 /**
	 * 云柜台|查询用户相关信息（目前只查营业部）
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.queryUserInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1001";
		paraMap["user_id"] = param.user_id;
		paraMap["login_id"] = param.login_id;
		paraMap["identity_type"] = param.identity_type;
		paraMap["identity_num"] = param.identity_num;
		paraMap["mobile"] = param.mobile;
		paraMap["email"] = param.email;
		paraMap["login_uid"] = param.login_uid;
		paraMap["login_type"] = param.login_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 * 云柜台|获取我的证券资产总览 ----包含股票、基金、理财部分
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.queryAssetList = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004427";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["moneytype"] = param.moneytype;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	}

	/**
	 *云柜台|查询公告信息
	 *功能号 1004478
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.showNotice = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004478";
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}

	/**
	 *云柜台|查询通知
	 *功能号 1004479
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.showInform = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004479";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}

	/**
	 *云柜台|查询私信
	 *功能号 1004480
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.showPrivateLetter = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004480";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *云柜台|根据id查询公告
	 *功能号 1004481
	 * @param param json格式入参
	 * @param id 公告ID
	 */
	mobileService.queryNoticeContent = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004481";
		paraMap["id"] = param.id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *云柜台|根据id查询通知
	 *功能号 1004482
	 * @param param json格式入参
	 * @param id 通知ID
	 */
	mobileService.queryInformContent = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004482";
		paraMap["id"] = param.id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *云柜台|根据id查询私信
	 *功能号 1004483
	 * @param param json格式入参
	 * @param id 私信ID
	 */
	mobileService.queryPriLetter = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004483";
		paraMap["id"] = param.id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *云柜台|根据开始时间和结束时间查询对账单信息
	 *功能号 1004485
	 * @param param json格式入参
	 * @param id 私信ID
	 */
	mobileService.queryBillInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004485";
		paraMap["user_id"] = param.user_id;
		paraMap["moneytype"] = param.moneytype;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 * 云柜台|查询营业部信息
	 */
	mobileService.queryBrachInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004180";
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 * 用户体系|修改联系地址
	 * @param param json格式入参
	 * @param callback 回调处理
	 * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
	 * 	isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
	 */
	mobileService.modifyUserInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1003";
		paraMap["user_id"] = param.user_id;
		paraMap["login_id"] = param.login_id;
		paraMap["name"] = param.name;
		paraMap["is_trade"] = param.is_trade;
		paraMap["trade_account"] = param.trade_account;
		paraMap["nick_name"] = param.nick_name;
		paraMap["sex"] = param.sex;
		paraMap["birthday"] = param.birthday;
		paraMap["mobile"] = param.mobile;
		paraMap["login_by_mobile"] = param.login_by_mobile;
		paraMap["email"] = param.email;
		paraMap["login_by_email"] = param.login_by_email;
		paraMap["is_freeze"] = param.is_freeze;
		paraMap["telephone"] = param.telephone;
		paraMap["address"] = param.address;
		paraMap["post_code"] = param.post_code;
		paraMap["qq_microblog"] = param.qq_microblog;
		paraMap["sina_microblog"] = param.sina_microblog;
		paraMap["qq"] = param.qq;
		paraMap["wechat"] = param.wechat;
		paraMap["recommend_person"] = param.recommend_person;
		paraMap["login_uid"] = param.login_uid;
		paraMap["channel_type"] = param.channel_type;
		paraMap["pwd_type"] = param.pwd_type;
		paraMap["pwd_value"] = param.pwd_value;
		paraMap["update_third"] = param.update_third;
		paraMap["fundid"] = param.fundid;
		
		paraMap["emergency_name"] = param.emergency_name;
		paraMap["emergency_relation"] = param.emergency_relation;
		paraMap["emergency_tel"] = param.emergency_tel;
		paraMap["emergency_mobile"] = param.emergency_mobile;
		paraMap["emergency_email"] = param.emergency_email;
		paraMap["emergency_address"] = param.emergency_address;
		paraMap["emergency_idtype"] = param.emergency_idtype;
		paraMap["emergency_idno"] = param.emergency_idno;
		paraMap["emergency_sex"] = param.emergency_sex;
		paraMap["emergency_zip"] = param.emergency_zip;
		paraMap["emergency_imetype"] = param.emergency_imetype;
		paraMap["emergency_imename"] = param.emergency_imename;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|查询用户基金公司开户状态（基金账号信息）
	 *功能号 1004188
	 * @param param json格式入参
	 * @param user_id 用户id
	 */
	mobileService.queryFundOpenState = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004188";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|基金账户查询（模拟——没用）
	 *功能号 1004189
	 * @param param json格式入参
	 * @param fundid 资金帐号
	 * @param qryflag 请求行数
	 * @param poststr 定位串
	 * @param tacode  基金公司
	 * @param taacc   基金帐号
	 * @param transacc 交易帐号
	 */
	mobileService.queryFundAccount = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004189";
		paraMap["fundid"] = param.fundid;
		paraMap["qryflag"] = param.qryflag;
		paraMap["count"] = param.count;
		paraMap["poststr"] = param.poststr;
		paraMap["tacode"] = param.tacode;
		paraMap["taacc"] = param.taacc;
		paraMap["transacc"] = param.transacc;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|基金开户
	 *功能号 1004190
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param address 详细地址
	 * @param postcode 邮编
	 * @param mobile 手机号码
	 * @param email 邮箱
	 * @param deliver_type 账单类型
	 * @param tacodes 基金公司代码列表
	 */
	mobileService.openFundAccount = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004190";
		paraMap["user_id"] = param.user_id;
		paraMap["address"] = param.address;
		paraMap["postcode"] = param.postcode;
		paraMap["mobile"] = param.mobile;
		paraMap["email"] = param.email;
		paraMap["deliver_type"] = param.deliver_type;
		paraMap["tacodes"] = param.tacodes;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|查询用户基金风险测评状态
	 *功能号 1004489
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.queryFundRiskState = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004489";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|查询基金风险测评题目
	 *功能号 1004490
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.queryFundRisk = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004490";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|基金开户|提交基金风险测评
	 *功能号 1004491
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param answer 答案
	 */
	mobileService.submitFundRisk = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004491";
		paraMap["user_id"] = param.user_id;
		paraMap["answer"] = param.answer;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|风险警示股票（ST等）权限设置
	 *功能号 1004171
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param jsondata 签名和原文数据
	 * @param macaddr mac地址
	 * @param ipaddr  ip地址
	 * @param checksign 是否验签
	 * @param sign_source_flag 签名原文来源
	 * @param certType 证书类型
	 */
	mobileService.setSTPermission = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004171";
		paraMap["user_id"] = param.user_id;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		paraMap["certType"] = param.certType;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|获取开通上海风险警示买入交易权限业务办理数据 (查询是否开通上海风险警示)
	 *功能号 1004434
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.querySTState = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "1004434";
		paraMap["user_id"] = param.user_id;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 查询用户现金宝信息
	 *功能号 2004002
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @fund_account 资金账号
	 */
	mobileService.queryCashTreasureInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004002";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 验签，开通现金宝
	 *功能号 2004001
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @fund_account 资金账号
	 */
	mobileService.cashCheckSign = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004001";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		paraMap["certType"] = param.certType;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 查询用户现金宝份额
	 *功能号 2004003
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @fund_account 资金账号
	 */
	mobileService.queryCashTreaShare = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004003";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 现金宝解约			
	 *功能号 2004004
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @fund_account 资金账号
	 */
	mobileService.cashTreasureTerm = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004004";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 保留额度设置				
	 *功能号 2004005
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @fund_account 资金账号
	 */
	mobileService.limitSet = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004005";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["expiry_date"] = param.expiry_date;
		paraMap["reserve_money"] = param.reserve_money;
		paraMap["operation_type"] = param.operation_type;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 预约取款操作							
	 *功能号 2004006
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @pram fund_account 资金账号
	 * @param reserve_date 预约取款日期
	 * @param operation_type 操作方式 0-增加 1-修改 2-删除
	 * @param capital_limit 资金保留额度
	 */
	mobileService.subscribeWithdrawing = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004006";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;
		paraMap["reserve_date"] = param.reserve_date;
		paraMap["operation_type"] = param.operation_type;
		paraMap["capital_limit"] = param.capital_limit;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝 --- 预约取款申请记录查询			
	 *功能号 2004007
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryWithdrawingRecord = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004007";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|融资融券 --- 融资融券股东查询			
	 *功能号 1004051
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryCreditAccountInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004051";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|融资融券 --- 信用资产查询			
	 *功能号 1004052
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryCreditAssetInfo = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004052";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝|查询用户电子签名约定书是否签署			
	 *功能号 2004008
	 * @param param json格式入参
	 * @param user_id 用户编号
	 */
	mobileService.queryIsSignCasePro = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004008";
		paraMap["user_id"] = param.user_id;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝|签署协议，申请电子签名约定书			
	 *功能号2004009
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 * @param jsondata 签名和原文数据
	 * @param macaddr mac地址
	 * @param ipaddr ip地址
	 * @param checksign 是否验签
	 * @param sign_source_flag 签名原文来源
	 * @param certType 证书类型
	 */
	mobileService.signCaseProtocol = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004009";
		paraMap["user_id"] = param.user_id;
//		paraMap["fund_account"] = param.fund_account;
		paraMap["jsondata"] = param.jsondata;
		paraMap["macaddr"] = param.macaddr;
		paraMap["ipaddr"] = param.ipaddr;
		paraMap["checksign"] = param.checksign;
		paraMap["sign_source_flag"] = param.sign_source_flag;
		paraMap["certType"] = param.certType;
		
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝|查询基金风险测评状态			
	 *功能号 2004010
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryCashRiskState = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004010";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
	/**
	 *业务办理|现金宝|查询是否开通过基金账户			
	 *功能号 2004011
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryIsOpenFundAccount = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004011";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}

	/**
	 *业务办理|现金宝 --- 查询预约取款交易日
	 *功能号 2004012
	 * @param param json格式入参
	 * @param user_id 用户编号
	 * @param fund_account 资金账号
	 */
	mobileService.queryPhysDate = function(param,callback,ctrlParam) {
		var paraMap = {};
		paraMap["funcNo"] = "2004012";
		paraMap["user_id"] = param.user_id;
		paraMap["fund_account"] = param.fund_account;

		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
		reqParamVo.setUrl(global.serverPath);
		commonInvoke(paraMap, callback,ctrlParam,reqParamVo);
	}
	
    /********************************应用接口结束********************************/
});