/**
 * 这里写模块内部的消息处理函数，供原生回调H5
 */
define(function(require, exports, module){
	var	gconfig = require("gconfig");
	var	global = gconfig.global;
	var appUtils = require("appUtils");
	var	layerUtils = require("layerUtils");
	var oMyMsgFunction = {}; // 暴露给外部的对象
	var msgFunction = require("msgFunction"); // 加载 plugins 目录里面公用的 msgFunction
	var nativePluginService = require("nativePluginService");
	
	/*将本文件里面的函数和 plugins 目录里面公用的 msgFunction 中的函数进行合并操作*/
	msgFunction.conbine(oMyMsgFunction);
	/*将本文件里面的函数和 plugins 目录里面公用的 msgFunction 中的函数进行合并操作，请务必将这句代码放在模块最前面*/
	
	/**
	 * 公用		
	 * 弹出通讯录，用于选择联系人的信息，选择完毕后回调H5
	 * 说明：通讯录插件的调用必须要写在页面UI的事件处理函数中，否则多模块开发原生无法获取到当前激活的模块从而导致无法回调H5
	 * @param funcNo 50223
	 * @param name String 名称 Y
	 * @param phone String 手机号码 Y
	 */
	oMyMsgFunction.function50223 = function(paramMap) 
	{
		var selPhoneCallback = window.selPhoneCallback; // 选择电话联系人的回调函数
		if(selPhoneCallback)
		{
			selPhoneCallback(paramMap);
		}
	};
	
	/**
	 * 公用		
	 * 日期控件回调H5
	 * 说明：日期控件的调用必须要写在页面UI的事件处理函数中，否则多模块开发原生无法获取到当前激活的模块从而导致无法回调H5
	 * @param funcNo 50251
	 * @param date String 日期 Y
	 * @param selector String H5的元素选择器 N
	 */
	oMyMsgFunction.function50251 = function(paramMap) 
	{
		paramMap = paramMap || {};
		var selDateCallback = window.selDateCallback; 			  // 选择日期的回调函数
		if(selDateCallback)
		{
			selDateCallback(paramMap);
		}
	};

	/**
	 * 公用
	 * 日期控件回调H5
	 * 说明：日期控件的调用必须要写在页面UI的事件处理函数中，否则多模块开发原生无法获取到当前激活的模块从而导致无法回调H5
	 * @param funcNo 50119
	 * @param date String 日期 Y
	 * @param selector String H5的元素选择器 N
	 */
	oMyMsgFunction.function60601 = function(paramMap)
	{
		var pageId = $("body .page[data-display='block']").attr("id");
		var pageCode = pageId.replace("_", "/");
		require.async(gconfig.scriptsPath + pageCode, function(page) {
			page.selCustomDateCallback(paramMap);
		});
    };

	
	/**
	 * 公用		
	 * 设置系统软件的主题风格
	 * @param funcNo 50104
	 * @param theme String 主题颜色(见数据字典) Y 0：红色，1：蓝色，2：黑色，3：黄色，9：绿色
	 */
	oMyMsgFunction.function50104 = function(paramMap) 
	{
		if(paramMap)
		{
			var $appCss = $("head>link[href*='" + gconfig.firstLoadCss[0] + "']");
			var skinMap = {0: "red", 1: "blue", 2: "black", 3: "yellow", 9: "green"};
			var href = gconfig.cssPath + "style_" + skinMap[paramMap.theme] + ".css";
			gconfig.firstLoadCss[0] = href; // 修改当前皮肤对应的 css
			$appCss.attr("href", href);
			var originalOverflow = $("body").css("overflow");
			$("body").css("overflow", "auto"); // 强制浏览器重绘
			$("body").css("overflow", originalOverflow);
		}
	};

	/**
	 * 公用		
	 * 原生的信息提示框回调H5
	 * @param funcNo 50111
	 * @param flag	String	业务标志	N
	 */
	oMyMsgFunction.function50111 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert(paramMap.flag);
		}
	};

	/**
	 * 公用		
	 * 通知H5分享后的状态
	 * @param funcNo 50232
	 * @param shareType	String	分享平台（数据字典）	Y
	 * @param flag	String	分享状态（0：失败，1：成功)	Y
	 * @param info	String	备注信息	N
	 */
	oMyMsgFunction.function50232 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("通知H5分享后的状态50232" + JSON.stringify(paramMap));
		}
	};
	
	/**
	 * 公用		
	 * 验证手势密码中忘记密码，修改账号回调H5
	 * @param funcNo 50262
	 * @param type	String	类型(0：忘记密码，1：修改账号）	N
	 */
	oMyMsgFunction.function50262 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("验证手势密码中忘记密码，修改账号回调H550262" + JSON.stringify(paramMap));
		}
	};

	/**
	 * 公用		
	 * 扫描图片二维码的内容回调给H5页面	
	 * @param funcNo 50272
	 * @param content	String	内容	Y
	 */
	oMyMsgFunction.function50272 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("扫描图片二维码的内容回调给H5页面	50272" + JSON.stringify(paramMap));
		}
	};
	
	/**
	 * 行情跳转买卖			
	 * @param funcNo 50272
	 * @param content	String	内容	Y
	 */
	oMyMsgFunction.function60250 = function(paramMap) 
	{
		try{
			var type = paramMap.type;//买卖类型
			var code = paramMap.code;//股票代码
			var market = paramMap.market;//市场
			var param = {"stockCode":code};
			appUtils.setSStorageInfo("_loginInPageParam",JSON.stringify(param));
			if(type=="buy"){
				appUtils.setSStorageInfo("_loginInPageCode","stock/stockBuy");
				appUtils.pageInit(null,"stock/stockBuy",{"stockCode":code});
			}else{
				appUtils.setSStorageInfo("_loginInPageCode","stock/stockSell");
				appUtils.pageInit(null,"stock/stockSell",{"stockCode":code});
			}

		}catch(e){
			console.log("H5获取股票买卖传入数据解析JSON出错"+e.message);
	    }
	};
	
	/**
	 * 原生跳转H5模块
	 * @param paramMap json格式参数
	 */
	oMyMsgFunction.function60251 = function(paramMap) 
	{
		try{
			var funcModules ={"0":"newshare/apply",
					          "1":"credit/asset/asset", 
					          "2":"ggt/ggtBuy",
					          "3":"fund/fundApply",
					          "4":"otc/otcProducts",
					          "5":"",
					          "6":"banking/transfer",
					          "7":"banking/collection",
					          "8":"account/changePassword",
					          "9":""
			                   };
			var funcModule = paramMap.funcModule;//功能模块
			var userInfo = paramMap.userInfo;//用户信息
			var loginType = paramMap.loginType;//账户类别
			appUtils.setSStorageInfo("clientinfo",userInfo.clientinfo);
			appUtils.setSStorageInfo("jsessionid",userInfo.jsessionid);
			appUtils.setSStorageInfo("_isLoginIn","true");
			appUtils.setSStorageInfo("_lastDoTime",new Date().getTime());
			var topage = funcModules[funcModule];
			userInfo = JSON.stringify(userInfo);
			if(loginType=="0"){
				appUtils.setSStorageInfo("stock_userInfo",userInfo);
			}else{
				appUtils.setSStorageInfo("credit_userInfo",userInfo);
			}
		    //登录超时停留页面
			var loginPageCode=appUtils.getSStorageInfo("_loginInPageCode");  //超时时停留的页面
			var loginInPageParam=appUtils.getSStorageInfo("_loginInPageParam");
			appUtils.clearSStorage("_loginInPageCode"); 
			appUtils.clearSStorage("_loginInPageParam");
			if(loginPageCode && loginPageCode!=""){
				var param=JSON.parse(loginInPageParam);	
				topage=loginPageCode;
				appUtils.pageInit(null,topage,param);
				
			}else{
				 appUtils.pageInit(null,topage,{});
			}

		}catch(e){
			console.log("原生跳转H5模块传入数据解析JSON出错"+e.message);
	    }
	};
       
       /**
        *模块切换初始化
        */
       oMyMsgFunction.function50113 = function(param)
       {
       		var defaultPage = "myAccount/index";
            var toPage = param["toPage"] ? param["toPage"] : defaultPage;
            var type = param ? param["type"] : null;															//type:common用于标记普通模块，rzrqIdentify只用于标记信用资产
            if("ygt" == gconfig.projName){
            	var loginTypeVo = nativePluginService.function50041({"key":"login_type"});						//普通账号：stock 两融：credit
				var login_type = loginTypeVo.results[0].value;
            	var stockVo = nativePluginService.function50041({"key":"COMMON_LOGIN_STATE"});					//1、已登录
				var creditVo = nativePluginService.function50041({"key":"CREDIT_LOGIN_STATE"});     		    //1、已登录
				var stock_account = stockVo.results[0].value;
				var credit_account = creditVo.results[0].value;
				appUtils.setSStorageInfo("st", stockVo.results[0].value);
				appUtils.setSStorageInfo("ct", creditVo.results[0].value);
				var moduleName = nativePluginService.function50041({"key":"trade_module"});						//区分我的账户：普通账号：stock 两融：credit
				var ygt_module = nativePluginService.function50041({"key":"ygt_module"}).results[0].value;		//区分我的资产：普通账号：stock 两融：credit
                var trade_module = moduleName.results[0].value;
                var inform_module =nativePluginService.function50041({"key":"inform_module"}).results[0].value;  //区分通知
                var privl_module =nativePluginService.function50041({"key":"privl_module"}).results[0].value;  //区分私信
                if(toPage==defaultPage){ //我的，时候，清除私信，和通知标识
                	inform_module="";
                	privl_module="";
                }

				//如果是从非我的模块跳转过来，则直接取50113传过来的toPage
				if("common" != type && "rzrqIdentify" != type){
					/*否则先判断是否同时登录两种类型账号，同时登录:1、如果只在云柜台同时登录则直接根据最后一个登陆账号的类型决定跳转的toPage 2、同时登录后从交易切换我的
					首先判断交易选中的是那个类型的首页，根据trade_module决定跳转的toPage*/
					if("1" == stock_account && "1" == credit_account){
						if("stock" == login_type){
							if("credit" == trade_module){
								toPage = "credit/creditAccount";
							}else if("credit" == ygt_module){
								toPage = "credit/creditAsset";
							}else if("stock" == ygt_module){
								toPage = "asset/index";
                            }else if("inform" == inform_module){//普通账号 、两融账号都登陆，查看通知
    							toPage = "myAccount/inform";
    						}else if("privateLetter"==privl_module){ //普通账号 登陆，查看私信
    							toPage = "myAccount/privateLetter";
    						}else if("myAccount/message"==toPage){
    							toPage = "myAccount/message";
    						} 
							else{
								toPage = "myAccount/index";
							}
						}else if("credit" == login_type){
							if("stock" == trade_module){
								toPage = "myAccount/index";
							}else if("stock" == ygt_module){
								toPage = "asset/index";
							}else if("credit" == ygt_module){
								toPage = "credit/creditAsset";
							}else if("privateLetter"==privl_module){ //普通账号 、两融账号都登陆，查看私信
								toPage = "credit/creditprivateLetter";
							}else if("inform" == inform_module){//信用账号登陆，查看通知
								toPage = "credit/creditinform";
							}else if("myAccount/message"==toPage){
    							toPage = "myAccount/message";
    						} 
							else{
								toPage = "credit/creditAccount";
							}
						}
					}else if("stock" == login_type && "1" == stock_account){	//非同时登录，直接根据登陆类型和登陆状态决定跳转的toPage
						if("stock" == ygt_module){
							toPage = "asset/index";
						}
						else if("inform" == inform_module){//普通账号 登陆，查看通知
							toPage = "myAccount/inform";
						}
						else if("privateLetter"==privl_module){ //普通账号 登陆，查看私信
							toPage = "myAccount/privateLetter";
						}else if("myAccount/message"==toPage){
							toPage = "myAccount/message";
						} 
						else{
							toPage = "myAccount/index";
						}
					}else if("credit" == login_type && "1" == credit_account){  //非同时登录，直接根据登陆类型和登陆状态决定跳转的toPage
						if("credit" == ygt_module){
							toPage = "credit/creditAsset";
						}
						else if("inform" == inform_module){//信用账号登陆，查看通知
							toPage = "credit/creditinform";
						}
						else if("privateLetter"==privl_module){ //信用账号 登陆，查看私信
							toPage = "credit/creditprivateLetter";
						}else if("myAccount/message"==toPage){
							toPage = "myAccount/message";
						} 
						else{
							toPage = "credit/creditAccount";
						}
					}
				}else if("rzrqIdentify" == type){
					toPage = "credit/creditAsset";
				}
            }
            if(toPage && toPage == "default"){
                toPage = gconfig.defaultPage.pageCode;
            }
            require.async("sso",function(module){
                if(toPage && toPage.length > 0)
                {
                    var index = toPage.indexOf(".");
                    if(index > 0){
                          toPage = toPage.substring(0,index);
                    }
                    var curPageCode = module.getCurrentPageCode();
                    if(curPageCode != toPage){
                          module.hidePageContent(curPageCode);
                    }
                    else
					{
						// 防止同一个页面白屏的问题
						var originalOverflow = $("body").css("overflow");
						$("body").css("overflow", "scroll");
						setTimeout(function(){
							$("body").css("overflow", originalOverflow);
						}, 20);
					}
                    appUtils.pageInit("",toPage,param);
                }
                else
                {
                     module.reloadPageInit();
                }
            });
       };
       
       /**
        *统一退出回调
        */
       oMyMsgFunction.function60401 = function(param)
       {
		  if(param.error_no == 0)
		  {
			  require.async("sso",function(module){
			     module.goTologin();
			 });
		  }
		  else
		  {
		   	 layerUtils.iAlert(param.error_info);
		  }
       }
       
       /**
        *  系统退出
        */
       oMyMsgFunction.function60403 = function(param)
       {
           appUtils.clearSStorage("_isLogin");
           appUtils.clearSStorage(gconfig.projName + "_login_token");
            // 禁止信用、资金都登录后，切到“我的”，自动去到“证券交易”  刘宝-hsj -16-02-26
           nativePluginService.function50040({"key":gconfig.projName+"_login_state","value":""});
           require.async("common",function(common){
                   common.clearSessionUserInfo();
            });
            require.async("sso",function(module){
                var pageCode = module.getCurrentPageCode();
                var pageId = pageCode.split("/").join("_");
                $("#"+pageId).remove();
           });
           //调用退出登录接口，请求服务器，失效session
       };
       
       
       /**
        * 超时回调函数   add 2016-03-23
        */
       oMyMsgFunction.function60609 = function(param)
       {
           if(param.error_no==0){
        	   require.async("sso",function(module){
                  module.ssoLoginOut();
              });
        	   
           }else{
        	   layerUtils.iAlert(param.error_info);  
           }
       };
       
       
       
       
       
	
	module.exports = oMyMsgFunction;
});